"""`NACE1 Standard <https://ec.europa.eu/eurostat/documents/1965800/1978760/Copy+of+5225C5EEBF016050E0440003BA9322F9.xls/6e1aec88-f15b-4d0f-bccc-4ee505c7f810>`_.
"""
from ...types import Category, Classification, Standard, Standards

NACE1 = Standard(
    standard=Standards.NACE1,
    classes=[
        Classification("01.11", "Growing of cereals and other crops n.e.c.", Category.CLASS),
        Classification(
            "01.12", "Growing of vegetables, horticultural specialities and nursery products", Category.CLASS
        ),
        Classification("01.13", "Growing of fruit, nuts, beverage and spice crops", Category.CLASS),
        Classification("01.21", "Farming of cattle, dairy farming", Category.CLASS),
        Classification("01.22", "Farming of sheep, goats, horses, asses, mules and hinnies", Category.CLASS),
        Classification("01.23", "Farming of swine", Category.CLASS),
        Classification("01.24", "Farming of poultry", Category.CLASS),
        Classification("01.25", "Other farming of animals", Category.CLASS),
        Classification("01.3", "Growing of crops combined with farming of animals (mixed farming)", Category.GROUP),
        Classification("01.41", "Agricultural service activities; landscape gardening", Category.CLASS),
        Classification("01.42", "Animal husbandry service activities, except veterinary activities", Category.CLASS),
        Classification(
            "01.5", "Hunting, trapping and game propagation, including related service activities", Category.GROUP
        ),
        Classification("02.01", "Forestry and logging", Category.CLASS),
        Classification("02.02", "Forestry and logging related service activities", Category.CLASS),
        Classification("05.01", "Fishing", Category.CLASS),
        Classification("05.02", " Fish farming", Category.CLASS),
        Classification("10.1", "Mining and agglomeration of hard coal", Category.GROUP),
        Classification("10.2", "Mining and agglomeration of lignite", Category.GROUP),
        Classification("10.3", "Extraction and agglomeration of peat", Category.GROUP),
        Classification("11.1", "Extraction of crude petroleum and natural gas", Category.GROUP),
        Classification(
            "11.2", "Service activities incidental to oil and gas extraction, excluding surveying", Category.GROUP
        ),
        Classification("12", "Mining of uranium and thorium ores", Category.DIVISION),
        Classification("13.1", "Mining of iron ores", Category.GROUP),
        Classification("13.2", "Mining of non-ferrous metal ores, except uranium and thorium ores", Category.GROUP),
        Classification("14.11", "Quarrying of  ornamental and building stone", Category.CLASS),
        Classification("14.12", "Quarrying of limestone, gypsum and chalk", Category.CLASS),
        Classification("14.13", "Quarrying of slate", Category.CLASS),
        Classification("14.21", "Operation of gravel and sand pits", Category.CLASS),
        Classification("14.22", "Mining of clays and kaolin", Category.CLASS),
        Classification("14.3", "Mining of chemical and fertilizer minerals", Category.GROUP),
        Classification("14.4", "Production of salt", Category.GROUP),
        Classification("14.5", "Other mining and quarrying n.e.c.", Category.GROUP),
        Classification("15.11", "Production and preserving of meat", Category.CLASS),
        Classification("15.12", "Production and preserving of poultrymeat", Category.CLASS),
        Classification("15.13", "Production of meat and poultrymeat products", Category.CLASS),
        Classification("15.2", "Processing and preserving of fish and fish products", Category.GROUP),
        Classification("15.31", "Processing and preserving of potatoes", Category.CLASS),
        Classification("15.32", "Manufacture of fruit and vegetable juice", Category.CLASS),
        Classification("15.33", "Processing and preserving of fruit and vegetables n.e.c.", Category.CLASS),
        Classification("15.41", "Manufacture of crude oils and fats", Category.CLASS),
        Classification("15.42", "Manufacture of refined oils and fats", Category.CLASS),
        Classification("15.43", "Manufacture of margarine and similar edible fats", Category.CLASS),
        Classification("15.51", "Operation of dairies and cheese making", Category.CLASS),
        Classification("15.52", "Manufacture of ice cream", Category.CLASS),
        Classification("15.61", "Manufacture of grain mill products", Category.CLASS),
        Classification("15.62", "Manufacture of starches and starch products", Category.CLASS),
        Classification("15.71", "Manufacture of prepared feeds for farm animals", Category.CLASS),
        Classification("15.72", "Manufacture of prepared pet foods", Category.CLASS),
        Classification("15.81", "Manufacture of bread; manufacture of fresh pastry goods and cakes", Category.CLASS),
        Classification(
            "15.82",
            "Manufacture of rusks and biscuits; manufacture of preserved pastry goods and cakes",
            Category.CLASS,
        ),
        Classification("15.83", "Manufacture of sugar", Category.CLASS),
        Classification("15.84", "Manufacture of cocoa; chocolate and sugar confectionery", Category.CLASS),
        Classification(
            "15.85", "Manufacture of macaroni, noodles, couscous and similar farinaceous products", Category.CLASS
        ),
        Classification("15.86", "Processing of tea and coffee", Category.CLASS),
        Classification("15.87", "Manufacture of condiments and seasonings", Category.CLASS),
        Classification("15.88", "Manufacture of homogenised food preparations and dietetic food", Category.CLASS),
        Classification("15.89", "Manufacture of other food products n.e.c.", Category.CLASS),
        Classification("15.91", "Manufacture of distilled potable alcoholic beverages", Category.CLASS),
        Classification("15.92", "Production of ethyl alcohol from fermented materials", Category.CLASS),
        Classification("15.93", "Manufacture of wines", Category.CLASS),
        Classification("15.94", "Manufacture of cider and other fruit wines", Category.CLASS),
        Classification("15.95", "Manufacture of other non-distilled fermented beverages", Category.CLASS),
        Classification("15.96", "Manufacture of beer", Category.CLASS),
        Classification("15.97", "Manufacture of malt", Category.CLASS),
        Classification("15.98", "Production of mineral waters and soft drinks", Category.CLASS),
        Classification("16", "Manufacture of tobacco products", Category.DIVISION),
        Classification("17.11", "Preparation and spinning of cotton-type fibres", Category.CLASS),
        Classification("17.12", "Preparation and spinning of woollen-type fibres", Category.CLASS),
        Classification("17.13", "Preparation and spinning of worsted-type fibres", Category.CLASS),
        Classification("17.14", "Preparation and spinning of flax-type fibres", Category.CLASS),
        Classification(
            "17.15",
            "Throwing and preparation of silk, including from noils, and throwing and texturing of synthetic or artificial filament yarns",
            Category.CLASS,
        ),
        Classification("17.16", "Manufacture of sewing threads", Category.CLASS),
        Classification("17.17", "Preparation and spinning of other textile fibres", Category.CLASS),
        Classification("17.21", "Cotton-type weaving", Category.CLASS),
        Classification("17.22", "Woollen-type weaving", Category.CLASS),
        Classification("17.23", "Worsted-type weaving", Category.CLASS),
        Classification("17.24", "Silk-type weaving", Category.CLASS),
        Classification("17.25", "Other textile weaving", Category.CLASS),
        Classification("17.3", "Finishing of textiles", Category.GROUP),
        Classification("17.4", "Manufacture of made-up textile articles, except apparel", Category.GROUP),
        Classification("17.51", "Manufacture of carpets and rugs", Category.CLASS),
        Classification("17.52", "Manufacture of cordage, rope, twine and netting", Category.CLASS),
        Classification(
            "17.53", "Manufacture of non-wovens and articles made from non-wovens, except apparel", Category.CLASS
        ),
        Classification("17.54", "Manufacture of other textiles n.e.c.", Category.CLASS),
        Classification("17.6", "Manufacture of knitted and crocheted fabrics", Category.GROUP),
        Classification("17.71", "Manufacture of knitted and crocheted hosiery", Category.CLASS),
        Classification(
            "17.72", "Manufacture of knitted and crocheted pullovers, cardigans and similar articles", Category.CLASS
        ),
        Classification("18.1", "Manufacture of leather clothes", Category.GROUP),
        Classification("18.21", "Manufacture of workwear", Category.CLASS),
        Classification("18.22", "Manufacture of other outerwear", Category.CLASS),
        Classification("18.23", "Manufacture of underwear", Category.CLASS),
        Classification("18.24", "Manufacture of other wearing apparel and accessories n.e.c.", Category.CLASS),
        Classification("18.3", "Dressing and dyeing of fur; manufacture of articles of fur", Category.GROUP),
        Classification("19.1", "Tanning and dressing of leather", Category.GROUP),
        Classification("19.2", "Manufacture of luggage, handbags and the like, saddlery and harness", Category.GROUP),
        Classification("19.3", "Manufacture of footwear", Category.GROUP),
        Classification("20.1", "Sawmilling and planing of wood; impregnation of wood", Category.GROUP),
        Classification(
            "20.2",
            "Manufacture of veneer sheets; manufacture of plywood, laminboard, particle board, fibre board and other panels and boards",
            Category.GROUP,
        ),
        Classification("20.3", "Manufacture of builders' carpentry and joinery", Category.GROUP),
        Classification("20.4", "Manufacture of wooden containers", Category.GROUP),
        Classification("20.51", "Manufacture of other products of wood", Category.CLASS),
        Classification("20.52", "Manufacture of articles of cork, straw and plaiting materials", Category.CLASS),
        Classification("21.11", "Manufacture of pulp", Category.CLASS),
        Classification("21.12", "Manufacture of paper and paperboard", Category.CLASS),
        Classification(
            "21.21",
            "Manufacture of corrugated paper and paperboard and of containers of paper and paperboard",
            Category.CLASS,
        ),
        Classification("21.22", "Manufacture of household and sanitary goods and of toilet requisites", Category.CLASS),
        Classification("21.23", "Manufacture of paper stationery", Category.CLASS),
        Classification("21.24", "Manufacture of wallpaper", Category.CLASS),
        Classification("21.25", "Manufacture of other articles of paper and paperboard n.e.c.", Category.CLASS),
        Classification("22.11", "Publishing of books", Category.CLASS),
        Classification("22.12", "Publishing of newspapers", Category.CLASS),
        Classification("22.13", "Publishing of journals and periodicals", Category.CLASS),
        Classification("22.14", "Publishing of sound recordings", Category.CLASS),
        Classification("22.15", "Other publishing", Category.CLASS),
        Classification("22.21", "Printing of newspapers", Category.CLASS),
        Classification("22.22", "Printing n.e.c.", Category.CLASS),
        Classification("22.23", "Bookbinding ", Category.CLASS),
        Classification("22.24", "Pre-press activities", Category.CLASS),
        Classification("22.25", "Ancillary activities related to printing", Category.CLASS),
        Classification("22.31", "Reproduction of sound recording", Category.CLASS),
        Classification("22.32", "Reproduction of video recording", Category.CLASS),
        Classification("22.33", "Reproduction of computer media", Category.CLASS),
        Classification("23.1", "Manufacture of coke oven products", Category.GROUP),
        Classification("23.2", "Manufacture of refined petroleum products", Category.GROUP),
        Classification("23.3", "Processing of nuclear fuel", Category.GROUP),
        Classification("24.11", "Manufacture of industrial gases", Category.CLASS),
        Classification("24.12", "Manufacture of dyes and pigments", Category.CLASS),
        Classification("24.13", "Manufacture of other inorganic basic chemicals", Category.CLASS),
        Classification("24.14", "Manufacture of other organic basic chemicals", Category.CLASS),
        Classification("24.15", "Manufacture of fertilizers and nitrogen compounds", Category.CLASS),
        Classification("24.16", "Manufacture of plastics in primary forms", Category.CLASS),
        Classification("24.17", "Manufacture of synthetic rubber in primary forms", Category.CLASS),
        Classification("24.2", "Manufacture of pesticides and other agro-chemical products", Category.GROUP),
        Classification(
            "24.3", "Manufacture of paints, varnishes and similar coatings, printing ink and mastics", Category.GROUP
        ),
        Classification("24.41", "Manufacture of basic pharmaceutical products", Category.CLASS),
        Classification("24.42", "Manufacture of pharmaceutical preparations", Category.CLASS),
        Classification(
            "24.51", "Manufacture of soap and detergents, cleaning and polishing preparations", Category.CLASS
        ),
        Classification("24.52", "Manufacture of perfumes and toilet preparations", Category.CLASS),
        Classification("24.61", "Manufacture of explosives", Category.CLASS),
        Classification("24.62", "Manufacture of glues and gelatines", Category.CLASS),
        Classification("24.63", "Manufacture of essential oils", Category.CLASS),
        Classification("24.64", "Manufacture of photographic chemical material", Category.CLASS),
        Classification("24.65", "Manufacture of prepared unrecorded media", Category.CLASS),
        Classification("24.66", "Manufacture of other chemical products n.e.c.", Category.CLASS),
        Classification("24.7", "Manufacture of man-made fibres", Category.GROUP),
        Classification("25.11", "Manufacture of rubber tyres and tubes", Category.CLASS),
        Classification("25.12", "Retreading and rebuilding of rubber tyres", Category.CLASS),
        Classification("25.13", "Manufacture of other rubber products", Category.CLASS),
        Classification("25.21", "Manufacture of plastic plates, sheets, tubes and profiles", Category.CLASS),
        Classification("25.22", "Manufacture of plastic packing goods", Category.CLASS),
        Classification("25.23", "Manufacture of builders' ware of plastic", Category.CLASS),
        Classification("25.24", "Manufacture of other plastic products", Category.CLASS),
        Classification("26.11", "Manufacture of flat glass", Category.CLASS),
        Classification("26.12", "Shaping and processing of flat glass", Category.CLASS),
        Classification("26.13", "Manufacture of hollow glass", Category.CLASS),
        Classification("26.14", "Manufacture of glass fibres", Category.CLASS),
        Classification(
            "26.15", "Manufacture and processing of other glass, including technical glassware", Category.CLASS
        ),
        Classification("26.21", "Manufacture of ceramic household and ornamental articles", Category.CLASS),
        Classification("26.22", "Manufacture of ceramic sanitary fixtures", Category.CLASS),
        Classification("26.23", "Manufacture of ceramic insulators and insulating fittings", Category.CLASS),
        Classification("26.24", "Manufacture of other technical ceramic products", Category.CLASS),
        Classification("26.25", "Manufacture of other ceramic products", Category.CLASS),
        Classification("26.26", "Manufacture of refractory ceramic products", Category.CLASS),
        Classification("26.3", "Manufacture of ceramic tiles and flags", Category.GROUP),
        Classification("26.4", "Manufacture of bricks, tiles and construction products, in baked clay", Category.GROUP),
        Classification("26.51", "Manufacture of cement", Category.CLASS),
        Classification("26.52", "Manufacture of lime", Category.CLASS),
        Classification("26.53", "Manufacture of plaster", Category.CLASS),
        Classification("26.61", "Manufacture of concrete products for construction purposes", Category.CLASS),
        Classification("26.62", "Manufacture of plaster products for construction purposes", Category.CLASS),
        Classification("26.63", "Manufacture of ready-mixed concrete", Category.CLASS),
        Classification("26.64", "Manufacture of mortars", Category.CLASS),
        Classification("26.65", "Manufacture of fibre cement", Category.CLASS),
        Classification("26.66", "Manufacture of other articles of concrete, plaster and cement", Category.CLASS),
        Classification("26.7", "Cutting, shaping and finishing of ornamental and building stone", Category.GROUP),
        Classification("26.81", "Production of abrasive products", Category.CLASS),
        Classification("26.82", "Manufacture of other non-metallic mineral products n.e.c.", Category.CLASS),
        Classification("27.1", "Manufacture of basic iron and steel and of ferro-alloys ", Category.GROUP),
        Classification("27.21", "Manufacture of cast iron tubes", Category.CLASS),
        Classification("27.22", "Manufacture of steel tubes", Category.CLASS),
        Classification("27.31", "Cold drawing", Category.CLASS),
        Classification("27.32", "Cold rolling of narrow strip", Category.CLASS),
        Classification("27.33", "Cold forming or folding", Category.CLASS),
        Classification("27.34", "Wire drawing", Category.CLASS),
        Classification("27.41", "Precious metals production", Category.CLASS),
        Classification("27.42", "Aluminium production", Category.CLASS),
        Classification("27.43", "Lead, zinc and tin production", Category.CLASS),
        Classification("27.44", "Copper production", Category.CLASS),
        Classification("27.45", "Other non-ferrous metal production", Category.CLASS),
        Classification("27.51", "Casting of iron", Category.CLASS),
        Classification("27.52", "Casting of steel", Category.CLASS),
        Classification("27.53", "Casting of light metals", Category.CLASS),
        Classification("27.54", "Casting of other non-ferrous metals", Category.CLASS),
        Classification(
            "28", "Manufacture of fabricated metal products, except machinery and equipment", Category.DIVISION
        ),
        Classification("28.11", "Manufacture of metal structures and parts of structures", Category.CLASS),
        Classification("28.12", "Manufacture of builders' carpentry and joinery of metal", Category.CLASS),
        Classification("28.21", "Manufacture of tanks, reservoirs and containers of metal", Category.CLASS),
        Classification("28.22", "Manufacture of central heating radiators and boilers", Category.CLASS),
        Classification(
            "28.3", "Manufacture of steam generators, except central heating hot water boilers", Category.GROUP
        ),
        Classification(
            "28.4", "Forging, pressing, stamping and roll forming of metal; powder metallurgy", Category.GROUP
        ),
        Classification("28.51", "Treatment and coating of metals", Category.CLASS),
        Classification("28.52", "General mechanical engineering", Category.CLASS),
        Classification("28.61", "Manufacture of cutlery", Category.CLASS),
        Classification("28.62", "Manufacture of tools", Category.CLASS),
        Classification("28.63", "Manufacture of locks and hinges", Category.CLASS),
        Classification("28.71", "Manufacture of steel drums and similar containers", Category.CLASS),
        Classification("28.72", "Manufacture of light metal packaging", Category.CLASS),
        Classification("28.73", "Manufacture of wire products", Category.CLASS),
        Classification("28.74", "Manufacture of fasteners, screw machine products, chain and springs", Category.CLASS),
        Classification("28.75", "Manufacture of other fabricated metal products n.e.c.", Category.CLASS),
        Classification("29", "Manufacture of machinery and equipment n.e.c.", Category.DIVISION),
        Classification(
            "29.11", "Manufacture of engines and turbines, except aircraft, vehicle and cycle engines", Category.CLASS
        ),
        Classification("29.12", "Manufacture of pumps and compressors", Category.CLASS),
        Classification("29.13", "Manufacture of taps and valves", Category.CLASS),
        Classification("29.14", "Manufacture of bearings, gears, gearing and driving elements", Category.CLASS),
        Classification("29.21", "Manufacture of furnaces and furnace burners", Category.CLASS),
        Classification("29.22", "Manufacture of lifting and handling equipment", Category.CLASS),
        Classification("29.23", "Manufacture of non-domestic cooling and ventilation equipment", Category.CLASS),
        Classification("29.24", "Manufacture of other general purpose machinery n.e.c.", Category.CLASS),
        Classification("29.31", "Manufacture of agricultural tractors", Category.CLASS),
        Classification("29.32", "Manufacture of other agricultural and forestry machinery", Category.CLASS),
        Classification("29.41", "Manufacture of portable hand held power tools", Category.CLASS),
        Classification("29.42", "Manufacture of other metalworking machine tools", Category.CLASS),
        Classification("29.43", "Manufacture of other machine tools n.e.c.", Category.CLASS),
        Classification("29.51", "Manufacture of machinery for metallurgy", Category.CLASS),
        Classification("29.52", "Manufacture of machinery for mining, quarrying and construction", Category.CLASS),
        Classification("29.53", "Manufacture of machinery for food, beverage and tobacco processing", Category.CLASS),
        Classification("29.54", "Manufacture of machinery for textile, apparel and leather production", Category.CLASS),
        Classification("29.55", "Manufacture of machinery for paper and paperboard production", Category.CLASS),
        Classification("29.56", "Manufacture of other special purpose machinery n.e.c.", Category.CLASS),
        Classification("29.6", "Manufacture of weapons and ammunition", Category.GROUP),
        Classification("29.71", "Manufacture of electric domestic appliances", Category.CLASS),
        Classification("29.72", "Manufacture of non-electric domestic appliances", Category.CLASS),
        Classification("30", "Manufacture of office machinery and computers", Category.DIVISION),
        Classification("30.01", "Manufacture of office machinery", Category.CLASS),
        Classification("30.02", "Manufacture of computers and other information processing equipment", Category.CLASS),
        Classification("31", "Manufacture of electrical machinery and apparatus n.e.c.", Category.DIVISION),
        Classification("31.1", "Manufacture of electric motors, generators and transformers", Category.GROUP),
        Classification("31.2", "Manufacture of electricity distribution and control apparatus", Category.GROUP),
        Classification("31.3", "Manufacture of insulated wire and cable", Category.GROUP),
        Classification("31.4", "Manufacture of accumulators, primary cells and primary batteries", Category.GROUP),
        Classification("31.5", "Manufacture of lighting equipment and electric lamps", Category.GROUP),
        Classification("31.61", "Manufacture of electrical equipment for engines and vehicles n.e.c.", Category.CLASS),
        Classification("31.62", "Manufacture of other electrical equipment n.e.c.", Category.CLASS),
        Classification(
            "32", "Manufacture of radio, television and communication equipment and apparatus", Category.DIVISION
        ),
        Classification(
            "32.1", "Manufacture of electronic valves and tubes and other electronic components", Category.GROUP
        ),
        Classification(
            "32.2",
            "Manufacture of television and radio transmitters and apparatus for line telephony and line telegraphy",
            Category.GROUP,
        ),
        Classification(
            "32.3",
            "Manufacture of television and radio receivers, sound or video recording or reproducing apparatus and associated goods",
            Category.GROUP,
        ),
        Classification(
            "33", "Manufacture of medical, precision and optical instruments, watches and clocks", Category.DIVISION
        ),
        Classification(
            "33.1", "Manufacture of medical and surgical equipment and orthopaedic appliances", Category.GROUP
        ),
        Classification(
            "33.2",
            "Manufacture of instruments and appliances for measuring, checking, testing, navigating and other purposes, except industrial process control equipment",
            Category.GROUP,
        ),
        Classification("33.3", "Manufacture of industrial process control equipment", Category.GROUP),
        Classification("33.4", "Manufacture of optical instruments and photographic equipment", Category.GROUP),
        Classification("33.5", "Manufacture of watches and clocks", Category.GROUP),
        Classification("34", "Manufacture of motor vehicles, trailers and semi-trailers", Category.DIVISION),
        Classification("34.1", "Manufacture of motor vehicles", Category.GROUP),
        Classification(
            "34.2",
            "Manufacture of bodies (coachwork) for motor vehicles; manufacture of trailers and semi-trailers",
            Category.GROUP,
        ),
        Classification(
            "34.3", "Manufacture of parts and accessories for motor vehicles and their engines", Category.GROUP
        ),
        Classification("35", "Manufacture of other transport equipment", Category.DIVISION),
        Classification("35.11", "Building and repairing of ships", Category.CLASS),
        Classification("35.12", "Building and repairing of pleasure and sporting boats", Category.CLASS),
        Classification("35.2", "Manufacture of railway and tramway locomotives and rolling stock", Category.GROUP),
        Classification("35.3", "Manufacture of aircraft and spacecraft", Category.GROUP),
        Classification("35.41", "Manufacture of motorcycles", Category.CLASS),
        Classification("35.42", "Manufacture of bicycles", Category.CLASS),
        Classification("35.43", "Manufacture of invalid carriages", Category.CLASS),
        Classification("35.5", "Manufacture of other transport equipment n.e.c.", Category.GROUP),
        Classification("36", "Manufacture of furniture; manufacturing n.e.c.", Category.DIVISION),
        Classification("36.11", "Manufacture of chairs and seats", Category.CLASS),
        Classification("36.12", "Manufacture of other office and shop furniture", Category.CLASS),
        Classification("36.13", "Manufacture of other kitchen furniture", Category.CLASS),
        Classification("36.14", "Manufacture of other furniture", Category.CLASS),
        Classification("36.15", "Manufacture of mattresses", Category.CLASS),
        Classification("36.21", "Striking of coins ", Category.CLASS),
        Classification("36.22", "Manufacture of jewellery and related articles n.e.c.", Category.CLASS),
        Classification("36.3", "Manufacture of musical instruments", Category.GROUP),
        Classification("36.4", "Manufacture of sports goods", Category.GROUP),
        Classification("36.5", "Manufacture of games and toys", Category.GROUP),
        Classification("36.61", "Manufacture of imitation jewellery", Category.CLASS),
        Classification("36.62", "Manufacture of brooms and brushes", Category.CLASS),
        Classification("36.63", "Other manufacturing n.e.c.", Category.CLASS),
        Classification("37.1", "Recycling of metal waste and scrap", Category.GROUP),
        Classification("37.2", "Recycling of non-metal waste and scrap", Category.GROUP),
        Classification("40.11", "Production of electricity", Category.CLASS),
        Classification("40.12", "Transmission of electricity", Category.CLASS),
        Classification("40.13", "Distribution and trade of electricity", Category.CLASS),
        Classification("40.21", "Manufacture of gas", Category.CLASS),
        Classification("40.22", "Distribution and trade of gaseous fuels through mains", Category.CLASS),
        Classification("40.3", "Steam and hot water supply", Category.GROUP),
        Classification("41", "Collection, purification and distribution of water", Category.DIVISION),
        Classification("45.11", "Demolition and wrecking of buildings; earth moving", Category.CLASS),
        Classification("45.12", "Test drilling and boring", Category.CLASS),
        Classification("45.21", "General construction of buildings and civil engineering works", Category.CLASS),
        Classification("45.22", "Erection of roof covering and frames", Category.CLASS),
        Classification("45.23", "Construction of motorways, roads, airfields and sport facilities", Category.CLASS),
        Classification("45.24", "Construction of water projects", Category.CLASS),
        Classification("45.25", "Other construction work involving special trades", Category.CLASS),
        Classification("45.31", "Installation of electrical wiring and fittings", Category.CLASS),
        Classification("45.32", "Insulation work activities", Category.CLASS),
        Classification("45.33", "Plumbing", Category.CLASS),
        Classification("45.34", "Other building installation", Category.CLASS),
        Classification("45.41", "Plastering", Category.CLASS),
        Classification("45.42", "Joinery installation", Category.CLASS),
        Classification("45.43", "Floor and wall covering", Category.CLASS),
        Classification("45.44", "Painting and glazing", Category.CLASS),
        Classification("45.45", "Other building completion", Category.CLASS),
        Classification("45.5", "Renting of construction or demolition equipment with operator", Category.GROUP),
        Classification("50.1", "Sale of motor vehicles", Category.GROUP),
        Classification("50.2", "Maintenance and repair of motor vehicles", Category.GROUP),
        Classification("50.3", "Sale of motor vehicle parts and accessories", Category.GROUP),
        Classification(
            "50.4", "Sale, maintenance and repair of motorcycles and related parts and accessories", Category.GROUP
        ),
        Classification("50.5", "Retail sale of automotive fuel", Category.GROUP),
        Classification(
            "51.11",
            "Agents involved in the sale of agricultural raw materials, live animals, textile raw materials and semi-finished goods",
            Category.CLASS,
        ),
        Classification(
            "51.12", "Agents involved in the sale of fuels, ores, metals and industrial chemicals", Category.CLASS
        ),
        Classification("51.13", "Agents involved in the sale of timber and building materials", Category.CLASS),
        Classification(
            "51.14",
            "Agents involved in the sale of machinery, industrial equipment, ships and aircraft",
            Category.CLASS,
        ),
        Classification(
            "51.15",
            "Agents involved in the sale of furniture, household goods, hardware and ironmongery",
            Category.CLASS,
        ),
        Classification(
            "51.16", "Agents involved in the sale of textiles, clothing, footwear and leather goods", Category.CLASS
        ),
        Classification("51.17", "Agents involved in the sale of food, beverages and tobacco", Category.CLASS),
        Classification(
            "51.18",
            "Agents specialising in the sale of particular products or ranges of products n.e.c.",
            Category.CLASS,
        ),
        Classification("51.19", "Agents involved in the sale of a variety of goods", Category.CLASS),
        Classification("51.21", "Wholesale of grain, seeds and animal feeds", Category.CLASS),
        Classification("51.22", "Wholesale of flowers and plants", Category.CLASS),
        Classification("51.23", "Wholesale of live animals", Category.CLASS),
        Classification("51.24", "Wholesale of hides, skins and leather", Category.CLASS),
        Classification("51.25", "Wholesale of unmanufactured tobacco", Category.CLASS),
        Classification("51.31", "Wholesale of fruit and vegetables", Category.CLASS),
        Classification("51.32", "Wholesale of meat and meat products", Category.CLASS),
        Classification("51.33", "Wholesale of dairy produce, eggs and edible oils and fats", Category.CLASS),
        Classification("51.34", "Wholesale of alcoholic and other beverages", Category.CLASS),
        Classification("51.35", "Wholesale of tobacco products", Category.CLASS),
        Classification("51.36", "Wholesale of sugar and chocolate and sugar confectionery", Category.CLASS),
        Classification("51.37", "Wholesale of coffee, tea, cocoa and spices", Category.CLASS),
        Classification("51.38", "Wholesale of other food, including fish, crustaceans and molluscs", Category.CLASS),
        Classification("51.39", "Non-specialised wholesale of food, beverages and tobacco", Category.CLASS),
        Classification("51.41", "Wholesale of textiles", Category.CLASS),
        Classification("51.42", "Wholesale of clothing and footwear", Category.CLASS),
        Classification(
            "51.43", "Wholesale of electrical household appliances and radio and television goods", Category.CLASS
        ),
        Classification("51.44", "Wholesale of china and glassware, wallpaper and cleaning materials", Category.CLASS),
        Classification("51.45", "Wholesale of perfume and cosmetics", Category.CLASS),
        Classification("51.46", "Wholesale of pharmaceutical goods", Category.CLASS),
        Classification("51.47", "Wholesale of other household goods", Category.CLASS),
        Classification("51.51", "Wholesale of solid, liquid and gaseous fuels and related products", Category.CLASS),
        Classification("51.52", "Wholesale of metals and metal ores", Category.CLASS),
        Classification("51.53", "Wholesale of wood, construction materials and sanitary equipment", Category.CLASS),
        Classification("51.54", "Wholesale of hardware, plumbing and heating equipment and supplies", Category.CLASS),
        Classification("51.55", "Wholesale of chemical products", Category.CLASS),
        Classification("51.56", "Wholesale of other intermediate products", Category.CLASS),
        Classification("51.57", "Wholesale of waste and scrap", Category.CLASS),
        Classification("51.81", "Wholesale of machine tools", Category.CLASS),
        Classification("51.82", "Wholesale of mining, construction and civil engineering machinery", Category.CLASS),
        Classification(
            "51.83",
            "Wholesale of machinery for the textile industry and of sewing and knitting machines",
            Category.CLASS,
        ),
        Classification("51.84", "Wholesale of computers, computer peripheral equipment and software", Category.CLASS),
        Classification("51.85", "Wholesale of other office machinery and equipment", Category.CLASS),
        Classification("51.86", "Wholesale of other electronic parts and equipment", Category.CLASS),
        Classification(
            "51.87", "Wholesale of other machinery for use in industry, trade and navigation", Category.CLASS
        ),
        Classification(
            "51.88",
            "Wholesale of agricultural machinery and accessories and implements, including tractors",
            Category.CLASS,
        ),
        Classification("51.9", "Other wholesale", Category.GROUP),
        Classification(
            "52.11",
            "Retail sale in non-specialised stores with food, beverages or tobacco predominating",
            Category.CLASS,
        ),
        Classification("52.12", "Other retail sale in non-specialised stores", Category.CLASS),
        Classification("52.21", "Retail sale of fruit and vegetables", Category.CLASS),
        Classification("52.22", "Retail sale of meat and meat products", Category.CLASS),
        Classification("52.23", "Retail sale of fish, crustaceans and molluscs", Category.CLASS),
        Classification(
            "52.24", "Retail sale of bread, cakes, flour confectionery and sugar confectionery", Category.CLASS
        ),
        Classification("52.25", "Retail sale of alcoholic and other beverages", Category.CLASS),
        Classification("52.26", "Retail sale of tobacco products", Category.CLASS),
        Classification(
            "52.27", "Other retail sale of food, beverages and tobacco in specialised stores", Category.CLASS
        ),
        Classification("52.31", "Dispensing chemists", Category.CLASS),
        Classification("52.32", "Retail sale of medical and orthopaedic goods", Category.CLASS),
        Classification("52.33", "Retail sale of cosmetic and toilet articles", Category.CLASS),
        Classification("52.41", "Retail sale of textiles", Category.CLASS),
        Classification("52.42", "Retail sale of clothing", Category.CLASS),
        Classification("52.43", "Retail sale of footwear and leather goods", Category.CLASS),
        Classification(
            "52.44", "Retail sale of furniture, lighting equipment and household articles n.e.c.", Category.CLASS
        ),
        Classification(
            "52.45", "Retail sale of electrical household appliances and radio and television goods", Category.CLASS
        ),
        Classification("52.46", "Retail sale of hardware, paints and glass", Category.CLASS),
        Classification("52.47", "Retail sale of books, newspapers and stationery", Category.CLASS),
        Classification("52.48", "Other retail sale in specialised stores", Category.CLASS),
        Classification("52.5", "Retail sale of second-hand goods in stores", Category.GROUP),
        Classification("52.61", "Retail sale via mail order houses", Category.CLASS),
        Classification("52.62", "Retail sale via stalls and markets", Category.CLASS),
        Classification("52.63", "Other non-store retail sale", Category.CLASS),
        Classification("52.71", "Repair of boots, shoes and other articles of leather", Category.CLASS),
        Classification("52.72", "Repair of electrical household goods", Category.CLASS),
        Classification("52.73", "Repair of watches, clocks and jewellery", Category.CLASS),
        Classification("52.74", "Repair n.e.c.", Category.CLASS),
        Classification("55.1", "Hotels", Category.GROUP),
        Classification("55.21", "Youth hostels and mountain refuges", Category.CLASS),
        Classification("55.22", "Camping sites, including caravan sites", Category.CLASS),
        Classification("55.23", "Other provision of lodgings n.e.c.", Category.CLASS),
        Classification("55.3", "Restaurants", Category.GROUP),
        Classification("55.4", "Bars", Category.GROUP),
        Classification("55.51", "Canteens", Category.CLASS),
        Classification("55.52", "Catering", Category.CLASS),
        Classification("60.1", "Transport via railways", Category.GROUP),
        Classification("60.21", "Other scheduled passenger land transport", Category.CLASS),
        Classification("60.22", "Taxi operation", Category.CLASS),
        Classification("60.23", "Other land passenger transport", Category.CLASS),
        Classification("60.24", "Freight transport by road", Category.CLASS),
        Classification("60.3", "Transport via pipelines", Category.GROUP),
        Classification("61.1", "Sea and coastal water transport", Category.GROUP),
        Classification("61.2", "Inland water transport", Category.GROUP),
        Classification("62.1", "Scheduled air transport", Category.GROUP),
        Classification("62.2", "Non-scheduled air transport", Category.GROUP),
        Classification("62.3", "Space transport", Category.GROUP),
        Classification("63.11", "Cargo handling", Category.CLASS),
        Classification("63.12", "Storage and warehousing", Category.CLASS),
        Classification("63.21", "Other supporting land transport activities", Category.CLASS),
        Classification("63.22", "Other supporting water transport activities", Category.CLASS),
        Classification("63.23", "Other supporting air transport activities", Category.CLASS),
        Classification(
            "63.3",
            "Activities of travel agencies and tour operators; tourist assistance activities n.e.c.",
            Category.GROUP,
        ),
        Classification("63.4", "Activities of other transport agencies", Category.GROUP),
        Classification("64.11", "National post activities", Category.CLASS),
        Classification("64.12", "Courier activities other than national post activities", Category.CLASS),
        Classification("64.2", "Telecommunications", Category.GROUP),
        Classification("65.11", "Central banking", Category.CLASS),
        Classification("65.12", "Other monetary intermediation", Category.CLASS),
        Classification("65.21", "Financial leasing", Category.CLASS),
        Classification("65.22", "Other credit granting", Category.CLASS),
        Classification("65.23", "Other financial intermediation n.e.c.", Category.CLASS),
        Classification("66.01", "Life insurance", Category.CLASS),
        Classification("66.02", "Pension funding", Category.CLASS),
        Classification("66.03", "Non-life insurance", Category.CLASS),
        Classification("67.11", "Administration of financial markets", Category.CLASS),
        Classification("67.12", "Security broking and fund management", Category.CLASS),
        Classification("67.13", "Activities auxiliary to financial intermediation n.e.c.", Category.CLASS),
        Classification("67.2", "Activities auxiliary to insurance and pension funding", Category.GROUP),
        Classification("70.11", "Development and selling of real estate", Category.CLASS),
        Classification("70.12", "Buying and selling of own real estate", Category.CLASS),
        Classification("70.2", "Letting of own property", Category.GROUP),
        Classification("70.31", "Real estate agencies", Category.CLASS),
        Classification("70.32", "Management of real estate on a fee or contract basis", Category.CLASS),
        Classification("71.1", "Renting of automobiles", Category.GROUP),
        Classification("71.21", "Renting of other land transport equipment", Category.CLASS),
        Classification("71.22", "Renting of water transport equipment", Category.CLASS),
        Classification("71.23", "Renting of air transport equipment", Category.CLASS),
        Classification("71.31", "Renting of agricultural machinery and equipment", Category.CLASS),
        Classification(
            "71.32", "Renting of construction and civil engineering machinery and equipment", Category.CLASS
        ),
        Classification("71.33", "Renting of office machinery and equipment, including computers", Category.CLASS),
        Classification("71.34", "Renting of other machinery and equipment n.e.c.", Category.CLASS),
        Classification("71.4", "Renting of personal and household goods n.e.c.", Category.GROUP),
        Classification("72.1", "Hardware consultancy", Category.GROUP),
        Classification("72.21", "Publishing of software", Category.CLASS),
        Classification("72.22", "Other software consultancy and supply", Category.CLASS),
        Classification("72.3", "Data processing", Category.GROUP),
        Classification("72.4", "Database activities", Category.GROUP),
        Classification("72.5", "Maintenance and repair of office, accounting and computing machinery", Category.GROUP),
        Classification("72.6", "Other computer related activities", Category.GROUP),
        Classification(
            "73.1", "Research and experimental development on natural sciences and engineering", Category.GROUP
        ),
        Classification(
            "73.2", "Research and experimental development on social sciences and humanities", Category.GROUP
        ),
        Classification("74.11", "Legal activities", Category.CLASS),
        Classification("74.12", "Accounting, book-keeping and auditing activities; tax consultancy", Category.CLASS),
        Classification("74.13", "Market research and public opinion polling", Category.CLASS),
        Classification("74.14", "Business and management consultancy activities", Category.CLASS),
        Classification("74.15", "Management activities of holding companies", Category.CLASS),
        Classification(
            "74.2", "Architectural and engineering activities and related technical consultancy", Category.GROUP
        ),
        Classification("74.3", "Technical testing and analysis", Category.GROUP),
        Classification("74.4", "Advertising", Category.GROUP),
        Classification("74.5", "Labour recruitment and provision of personnel", Category.GROUP),
        Classification("74.6", "Investigation and security activities", Category.GROUP),
        Classification("74.7", "Industrial cleaning", Category.GROUP),
        Classification("74.81", "Photographic activities", Category.CLASS),
        Classification("74.82", "Packaging activities", Category.CLASS),
        Classification("74.85", "Secretarial and translation activities", Category.CLASS),
        Classification("74.86", "Call centre activities", Category.CLASS),
        Classification("74.87", "Other business activities n.e.c.", Category.CLASS),
        Classification("75.11", "General (overall) public service activities", Category.CLASS),
        Classification(
            "75.12",
            "Regulation of the activities of agencies that provide health care, education, cultural services and other social services, excluding social security",
            Category.CLASS,
        ),
        Classification(
            "75.13", "Regulation of and contribution to more efficient operation of business", Category.CLASS
        ),
        Classification("75.14", "Supporting service activities for the government as a whole", Category.CLASS),
        Classification("75.21", "Foreign affairs", Category.CLASS),
        Classification("75.22", "Defence activities", Category.CLASS),
        Classification("75.23", "Justice and judicial activities", Category.CLASS),
        Classification("75.24", "Public security, law and order activities", Category.CLASS),
        Classification("75.25", "Fire service activities", Category.CLASS),
        Classification("75.3", "Compulsory social security activities", Category.GROUP),
        Classification("80.1", "Primary education", Category.GROUP),
        Classification("80.21", "General secondary education", Category.CLASS),
        Classification("80.22", "Technical and vocational secondary education", Category.CLASS),
        Classification("80.3", "Higher education", Category.GROUP),
        Classification("80.41", "Driving school activities", Category.CLASS),
        Classification("80.42", "Adult and other education n.e.c.", Category.CLASS),
        Classification("85.11", "Hospital activities", Category.CLASS),
        Classification("85.12", "Medical practice activities", Category.CLASS),
        Classification("85.13", "Dental practice activities", Category.CLASS),
        Classification("85.14", "Other human health activities", Category.CLASS),
        Classification("85.2", "Veterinary activities", Category.GROUP),
        Classification("85.31", "Social work activities with accommodation", Category.CLASS),
        Classification("85.32", "Social work activities without accommodation", Category.CLASS),
        Classification("90.01", "Collection and treatment of sewage", Category.CLASS),
        Classification("90.02", "Collection and treatment of other waste", Category.CLASS),
        Classification("90.03", "Sanitation, remediation and similar activities", Category.CLASS),
        Classification("91.11", "Activities of business and employers' organizations", Category.CLASS),
        Classification("91.12", "Activities of professional organizations", Category.CLASS),
        Classification("91.2", "Activities of trade unions", Category.GROUP),
        Classification("91.31", "Activities of religious organizations", Category.CLASS),
        Classification("91.32", "Activities of political organizations", Category.CLASS),
        Classification("91.33", "Activities of other membership organizations n.e.c.", Category.CLASS),
        Classification("92.11", "Motion picture and video production", Category.CLASS),
        Classification("92.12", "Motion picture and video distribution", Category.CLASS),
        Classification("92.13", "Motion picture projection", Category.CLASS),
        Classification("92.2", "Radio and television activities", Category.GROUP),
        Classification("92.31", "Artistic and literary creation and interpretation", Category.CLASS),
        Classification("92.32", "Operation of arts facilities", Category.CLASS),
        Classification("92.33", "Fair and amusement park activities", Category.CLASS),
        Classification("92.34", "Other entertainment activities n.e.c.", Category.CLASS),
        Classification("92.4", "News agency activities", Category.GROUP),
        Classification("92.51", "Library and archives activities", Category.CLASS),
        Classification(
            "92.52", "Museums activities and preservation of historical sites and buildings", Category.CLASS
        ),
        Classification("92.53", "Botanical and zoological gardens and nature reserves activities", Category.CLASS),
        Classification("92.61", "Operation of sports arenas and stadiums", Category.CLASS),
        Classification("92.62", "Other sporting activities", Category.CLASS),
        Classification("92.71", "Gambling and betting activities", Category.CLASS),
        Classification("92.72", "Other recreational activities n.e.c.", Category.CLASS),
        Classification("93.01", "Washing and dry-cleaning of textile and fur products", Category.CLASS),
        Classification("93.02", "Hairdressing and other beauty treatment", Category.CLASS),
        Classification("93.03", "Funeral and related activities", Category.CLASS),
        Classification("93.04", "Physical well-being activities", Category.CLASS),
        Classification("93.05", "Other service activities n.e.c.", Category.CLASS),
        Classification("95", "Activities of households as employers of domestic staff", Category.DIVISION),
        Classification(
            "96", "Undifferentiated goods producing activities of private households for own use", Category.DIVISION
        ),
        Classification(
            "97", "Undifferentiated services producing activities of private households for own use", Category.DIVISION
        ),
        Classification("99", "Extra-territorial organizations and bodies", Category.DIVISION),
    ],
)



# -*- coding: utf-8 -*-
"""`Concordance between NACE2 and ISIC4 <https://unstats.un.org/unsd/classifications/Econ/tables/ISIC/NACE2_ISIC4/NACE2_ISIC4.txt>`_.
"""
from ...types import Concordance, Standards
from ..isic4 import ISIC4
from . import NACE2

NACE2_to_ISIC4 = Concordance(
    src=NACE2,
    dst=ISIC4,
    concordances=[
        ((Standards.NACE2, "A"), (Standards.ISIC4, "A")),
        ((Standards.NACE2, "01"), (Standards.ISIC4, "01")),
        ((Standards.NACE2, "01.1"), (Standards.ISIC4, "011")),
        ((Standards.NACE2, "01.11"), (Standards.ISIC4, "0111")),
        ((Standards.NACE2, "01.12"), (Standards.ISIC4, "0112")),
        ((Standards.NACE2, "01.13"), (Standards.ISIC4, "0113")),
        ((Standards.NACE2, "01.14"), (Standards.ISIC4, "0114")),
        ((Standards.NACE2, "01.15"), (Standards.ISIC4, "0115")),
        ((Standards.NACE2, "01.16"), (Standards.ISIC4, "0116")),
        ((Standards.NACE2, "01.19"), (Standards.ISIC4, "0119")),
        ((Standards.NACE2, "01.2"), (Standards.ISIC4, "012")),
        ((Standards.NACE2, "01.21"), (Standards.ISIC4, "0121")),
        ((Standards.NACE2, "01.22"), (Standards.ISIC4, "0122")),
        ((Standards.NACE2, "01.23"), (Standards.ISIC4, "0123")),
        ((Standards.NACE2, "01.24"), (Standards.ISIC4, "0124")),
        ((Standards.NACE2, "01.25"), (Standards.ISIC4, "0125")),
        ((Standards.NACE2, "01.26"), (Standards.ISIC4, "0126")),
        ((Standards.NACE2, "01.27"), (Standards.ISIC4, "0127")),
        ((Standards.NACE2, "01.28"), (Standards.ISIC4, "0128")),
        ((Standards.NACE2, "01.29"), (Standards.ISIC4, "0129")),
        ((Standards.NACE2, "01.3"), (Standards.ISIC4, "013")),
        ((Standards.NACE2, "01.30"), (Standards.ISIC4, "0130")),
        ((Standards.NACE2, "01.4"), (Standards.ISIC4, "014")),
        ((Standards.NACE2, "01.41"), (Standards.ISIC4, "0141")),
        ((Standards.NACE2, "01.42"), (Standards.ISIC4, "0141")),
        ((Standards.NACE2, "01.43"), (Standards.ISIC4, "0142")),
        ((Standards.NACE2, "01.44"), (Standards.ISIC4, "0143")),
        ((Standards.NACE2, "01.45"), (Standards.ISIC4, "0144")),
        ((Standards.NACE2, "01.46"), (Standards.ISIC4, "0145")),
        ((Standards.NACE2, "01.47"), (Standards.ISIC4, "0146")),
        ((Standards.NACE2, "01.49"), (Standards.ISIC4, "0149")),
        ((Standards.NACE2, "01.5"), (Standards.ISIC4, "015")),
        ((Standards.NACE2, "01.50"), (Standards.ISIC4, "0150")),
        ((Standards.NACE2, "01.6"), (Standards.ISIC4, "016")),
        ((Standards.NACE2, "01.61"), (Standards.ISIC4, "0161")),
        ((Standards.NACE2, "01.62"), (Standards.ISIC4, "0162")),
        ((Standards.NACE2, "01.63"), (Standards.ISIC4, "0163")),
        ((Standards.NACE2, "01.64"), (Standards.ISIC4, "0164")),
        ((Standards.NACE2, "01.7"), (Standards.ISIC4, "017")),
        ((Standards.NACE2, "01.70"), (Standards.ISIC4, "0170")),
        ((Standards.NACE2, "02"), (Standards.ISIC4, "02")),
        ((Standards.NACE2, "02.1"), (Standards.ISIC4, "021")),
        ((Standards.NACE2, "02.10"), (Standards.ISIC4, "0210")),
        ((Standards.NACE2, "02.2"), (Standards.ISIC4, "022")),
        ((Standards.NACE2, "02.20"), (Standards.ISIC4, "0220")),
        ((Standards.NACE2, "02.3"), (Standards.ISIC4, "023")),
        ((Standards.NACE2, "02.30"), (Standards.ISIC4, "0230")),
        ((Standards.NACE2, "02.4"), (Standards.ISIC4, "024")),
        ((Standards.NACE2, "02.40"), (Standards.ISIC4, "0240")),
        ((Standards.NACE2, "03"), (Standards.ISIC4, "03")),
        ((Standards.NACE2, "03.1"), (Standards.ISIC4, "031")),
        ((Standards.NACE2, "03.11"), (Standards.ISIC4, "0311")),
        ((Standards.NACE2, "03.12"), (Standards.ISIC4, "0312")),
        ((Standards.NACE2, "03.2"), (Standards.ISIC4, "032")),
        ((Standards.NACE2, "03.21"), (Standards.ISIC4, "0321")),
        ((Standards.NACE2, "03.22"), (Standards.ISIC4, "0322")),
        ((Standards.NACE2, "B"), (Standards.ISIC4, "B")),
        ((Standards.NACE2, "05"), (Standards.ISIC4, "05")),
        ((Standards.NACE2, "05.1"), (Standards.ISIC4, "051")),
        ((Standards.NACE2, "05.10"), (Standards.ISIC4, "0510")),
        ((Standards.NACE2, "05.2"), (Standards.ISIC4, "052")),
        ((Standards.NACE2, "05.20"), (Standards.ISIC4, "0520")),
        ((Standards.NACE2, "06"), (Standards.ISIC4, "06")),
        ((Standards.NACE2, "06.1"), (Standards.ISIC4, "061")),
        ((Standards.NACE2, "06.10"), (Standards.ISIC4, "0610")),
        ((Standards.NACE2, "06.2"), (Standards.ISIC4, "062")),
        ((Standards.NACE2, "06.20"), (Standards.ISIC4, "0620")),
        ((Standards.NACE2, "07"), (Standards.ISIC4, "07")),
        ((Standards.NACE2, "07.1"), (Standards.ISIC4, "071")),
        ((Standards.NACE2, "07.10"), (Standards.ISIC4, "0710")),
        ((Standards.NACE2, "07.2"), (Standards.ISIC4, "072")),
        ((Standards.NACE2, "07.21"), (Standards.ISIC4, "0721")),
        ((Standards.NACE2, "07.29"), (Standards.ISIC4, "0729")),
        ((Standards.NACE2, "08"), (Standards.ISIC4, "08")),
        ((Standards.NACE2, "08.1"), (Standards.ISIC4, "081")),
        ((Standards.NACE2, "08.11"), (Standards.ISIC4, "0810")),
        ((Standards.NACE2, "08.12"), (Standards.ISIC4, "0810")),
        ((Standards.NACE2, "08.9"), (Standards.ISIC4, "089")),
        ((Standards.NACE2, "08.91"), (Standards.ISIC4, "0891")),
        ((Standards.NACE2, "08.92"), (Standards.ISIC4, "0892")),
        ((Standards.NACE2, "08.93"), (Standards.ISIC4, "0893")),
        ((Standards.NACE2, "08.99"), (Standards.ISIC4, "0899")),
        ((Standards.NACE2, "09"), (Standards.ISIC4, "09")),
        ((Standards.NACE2, "09.1"), (Standards.ISIC4, "091")),
        ((Standards.NACE2, "09.10"), (Standards.ISIC4, "0910")),
        ((Standards.NACE2, "09.9"), (Standards.ISIC4, "099")),
        ((Standards.NACE2, "09.90"), (Standards.ISIC4, "0990")),
        ((Standards.NACE2, "C"), (Standards.ISIC4, "C")),
        ((Standards.NACE2, "10"), (Standards.ISIC4, "10")),
        ((Standards.NACE2, "10.1"), (Standards.ISIC4, "101")),
        ((Standards.NACE2, "10.11"), (Standards.ISIC4, "1010")),
        ((Standards.NACE2, "10.12"), (Standards.ISIC4, "1010")),
        ((Standards.NACE2, "10.13"), (Standards.ISIC4, "1010")),
        ((Standards.NACE2, "10.2"), (Standards.ISIC4, "102")),
        ((Standards.NACE2, "10.20"), (Standards.ISIC4, "1020")),
        ((Standards.NACE2, "10.3"), (Standards.ISIC4, "103")),
        ((Standards.NACE2, "10.31"), (Standards.ISIC4, "1030")),
        ((Standards.NACE2, "10.32"), (Standards.ISIC4, "1030")),
        ((Standards.NACE2, "10.39"), (Standards.ISIC4, "1030")),
        ((Standards.NACE2, "10.4"), (Standards.ISIC4, "104")),
        ((Standards.NACE2, "10.41"), (Standards.ISIC4, "1040")),
        ((Standards.NACE2, "10.42"), (Standards.ISIC4, "1040")),
        ((Standards.NACE2, "10.5"), (Standards.ISIC4, "105")),
        ((Standards.NACE2, "10.51"), (Standards.ISIC4, "1050")),
        ((Standards.NACE2, "10.52"), (Standards.ISIC4, "1050")),
        ((Standards.NACE2, "10.6"), (Standards.ISIC4, "106")),
        ((Standards.NACE2, "10.61"), (Standards.ISIC4, "1061")),
        ((Standards.NACE2, "10.62"), (Standards.ISIC4, "1062")),
        ((Standards.NACE2, "10.7"), (Standards.ISIC4, "107")),
        ((Standards.NACE2, "10.71"), (Standards.ISIC4, "1071")),
        ((Standards.NACE2, "10.72"), (Standards.ISIC4, "1071")),
        ((Standards.NACE2, "10.73"), (Standards.ISIC4, "1074")),
        ((Standards.NACE2, "10.8"), (Standards.ISIC4, "107")),
        ((Standards.NACE2, "10.81"), (Standards.ISIC4, "1072")),
        ((Standards.NACE2, "10.82"), (Standards.ISIC4, "1073")),
        ((Standards.NACE2, "10.83"), (Standards.ISIC4, "1079")),
        ((Standards.NACE2, "10.84"), (Standards.ISIC4, "1079")),
        ((Standards.NACE2, "10.85"), (Standards.ISIC4, "1075")),
        ((Standards.NACE2, "10.86"), (Standards.ISIC4, "1079")),
        ((Standards.NACE2, "10.89"), (Standards.ISIC4, "1079")),
        ((Standards.NACE2, "10.9"), (Standards.ISIC4, "108")),
        ((Standards.NACE2, "10.91"), (Standards.ISIC4, "1080")),
        ((Standards.NACE2, "10.92"), (Standards.ISIC4, "1080")),
        ((Standards.NACE2, "11"), (Standards.ISIC4, "11")),
        ((Standards.NACE2, "11.0"), (Standards.ISIC4, "110")),
        ((Standards.NACE2, "11.01"), (Standards.ISIC4, "1101")),
        ((Standards.NACE2, "11.02"), (Standards.ISIC4, "1102")),
        ((Standards.NACE2, "11.03"), (Standards.ISIC4, "1102")),
        ((Standards.NACE2, "11.04"), (Standards.ISIC4, "1102")),
        ((Standards.NACE2, "11.05"), (Standards.ISIC4, "1103")),
        ((Standards.NACE2, "11.06"), (Standards.ISIC4, "1103")),
        ((Standards.NACE2, "11.07"), (Standards.ISIC4, "1104")),
        ((Standards.NACE2, "12"), (Standards.ISIC4, "12")),
        ((Standards.NACE2, "12.0"), (Standards.ISIC4, "120")),
        ((Standards.NACE2, "12.00"), (Standards.ISIC4, "1200")),
        ((Standards.NACE2, "13"), (Standards.ISIC4, "13")),
        ((Standards.NACE2, "13.1"), (Standards.ISIC4, "131")),
        ((Standards.NACE2, "13.10"), (Standards.ISIC4, "1311")),
        ((Standards.NACE2, "13.2"), (Standards.ISIC4, "131")),
        ((Standards.NACE2, "13.20"), (Standards.ISIC4, "1312")),
        ((Standards.NACE2, "13.3"), (Standards.ISIC4, "131")),
        ((Standards.NACE2, "13.30"), (Standards.ISIC4, "1313")),
        ((Standards.NACE2, "13.9"), (Standards.ISIC4, "139")),
        ((Standards.NACE2, "13.91"), (Standards.ISIC4, "1391")),
        ((Standards.NACE2, "13.92"), (Standards.ISIC4, "1392")),
        ((Standards.NACE2, "13.93"), (Standards.ISIC4, "1393")),
        ((Standards.NACE2, "13.94"), (Standards.ISIC4, "1394")),
        ((Standards.NACE2, "13.95"), (Standards.ISIC4, "1399")),
        ((Standards.NACE2, "13.96"), (Standards.ISIC4, "1399")),
        ((Standards.NACE2, "13.99"), (Standards.ISIC4, "1399")),
        ((Standards.NACE2, "14"), (Standards.ISIC4, "14")),
        ((Standards.NACE2, "14.1"), (Standards.ISIC4, "141")),
        ((Standards.NACE2, "14.11"), (Standards.ISIC4, "1410")),
        ((Standards.NACE2, "14.12"), (Standards.ISIC4, "1410")),
        ((Standards.NACE2, "14.13"), (Standards.ISIC4, "1410")),
        ((Standards.NACE2, "14.14"), (Standards.ISIC4, "1410")),
        ((Standards.NACE2, "14.19"), (Standards.ISIC4, "1410")),
        ((Standards.NACE2, "14.2"), (Standards.ISIC4, "142")),
        ((Standards.NACE2, "14.20"), (Standards.ISIC4, "1420")),
        ((Standards.NACE2, "14.3"), (Standards.ISIC4, "143")),
        ((Standards.NACE2, "14.31"), (Standards.ISIC4, "1430")),
        ((Standards.NACE2, "14.39"), (Standards.ISIC4, "1430")),
        ((Standards.NACE2, "15"), (Standards.ISIC4, "15")),
        ((Standards.NACE2, "15.1"), (Standards.ISIC4, "151")),
        ((Standards.NACE2, "15.11"), (Standards.ISIC4, "1511")),
        ((Standards.NACE2, "15.12"), (Standards.ISIC4, "1512")),
        ((Standards.NACE2, "15.2"), (Standards.ISIC4, "152")),
        ((Standards.NACE2, "15.20"), (Standards.ISIC4, "1520")),
        ((Standards.NACE2, "16"), (Standards.ISIC4, "16")),
        ((Standards.NACE2, "16.1"), (Standards.ISIC4, "161")),
        ((Standards.NACE2, "16.10"), (Standards.ISIC4, "1610")),
        ((Standards.NACE2, "16.2"), (Standards.ISIC4, "162")),
        ((Standards.NACE2, "16.21"), (Standards.ISIC4, "1621")),
        ((Standards.NACE2, "16.22"), (Standards.ISIC4, "1622")),
        ((Standards.NACE2, "16.23"), (Standards.ISIC4, "1622")),
        ((Standards.NACE2, "16.24"), (Standards.ISIC4, "1623")),
        ((Standards.NACE2, "16.29"), (Standards.ISIC4, "1629")),
        ((Standards.NACE2, "17"), (Standards.ISIC4, "17")),
        ((Standards.NACE2, "17.1"), (Standards.ISIC4, "170")),
        ((Standards.NACE2, "17.11"), (Standards.ISIC4, "1701")),
        ((Standards.NACE2, "17.12"), (Standards.ISIC4, "1701")),
        ((Standards.NACE2, "17.2"), (Standards.ISIC4, "170")),
        ((Standards.NACE2, "17.21"), (Standards.ISIC4, "1702")),
        ((Standards.NACE2, "17.22"), (Standards.ISIC4, "1709")),
        ((Standards.NACE2, "17.23"), (Standards.ISIC4, "1709")),
        ((Standards.NACE2, "17.24"), (Standards.ISIC4, "1709")),
        ((Standards.NACE2, "17.29"), (Standards.ISIC4, "1709")),
        ((Standards.NACE2, "18"), (Standards.ISIC4, "18")),
        ((Standards.NACE2, "18.1"), (Standards.ISIC4, "181")),
        ((Standards.NACE2, "18.11"), (Standards.ISIC4, "1811")),
        ((Standards.NACE2, "18.12"), (Standards.ISIC4, "1811")),
        ((Standards.NACE2, "18.13"), (Standards.ISIC4, "1812")),
        ((Standards.NACE2, "18.14"), (Standards.ISIC4, "1812")),
        ((Standards.NACE2, "18.2"), (Standards.ISIC4, "182")),
        ((Standards.NACE2, "18.20"), (Standards.ISIC4, "1820")),
        ((Standards.NACE2, "19"), (Standards.ISIC4, "19")),
        ((Standards.NACE2, "19.1"), (Standards.ISIC4, "191")),
        ((Standards.NACE2, "19.10"), (Standards.ISIC4, "1910")),
        ((Standards.NACE2, "19.2"), (Standards.ISIC4, "192")),
        ((Standards.NACE2, "19.20"), (Standards.ISIC4, "1920")),
        ((Standards.NACE2, "20"), (Standards.ISIC4, "20")),
        ((Standards.NACE2, "20.1"), (Standards.ISIC4, "201")),
        ((Standards.NACE2, "20.11"), (Standards.ISIC4, "2011")),
        ((Standards.NACE2, "20.12"), (Standards.ISIC4, "2011")),
        ((Standards.NACE2, "20.13"), (Standards.ISIC4, "2011")),
        ((Standards.NACE2, "20.14"), (Standards.ISIC4, "2011")),
        ((Standards.NACE2, "20.15"), (Standards.ISIC4, "2012")),
        ((Standards.NACE2, "20.16"), (Standards.ISIC4, "2013")),
        ((Standards.NACE2, "20.17"), (Standards.ISIC4, "2013")),
        ((Standards.NACE2, "20.2"), (Standards.ISIC4, "202")),
        ((Standards.NACE2, "20.20"), (Standards.ISIC4, "2021")),
        ((Standards.NACE2, "20.3"), (Standards.ISIC4, "202")),
        ((Standards.NACE2, "20.30"), (Standards.ISIC4, "2022")),
        ((Standards.NACE2, "20.4"), (Standards.ISIC4, "202")),
        ((Standards.NACE2, "20.41"), (Standards.ISIC4, "2023")),
        ((Standards.NACE2, "20.42"), (Standards.ISIC4, "2023")),
        ((Standards.NACE2, "20.5"), (Standards.ISIC4, "202")),
        ((Standards.NACE2, "20.51"), (Standards.ISIC4, "2029")),
        ((Standards.NACE2, "20.52"), (Standards.ISIC4, "2029")),
        ((Standards.NACE2, "20.53"), (Standards.ISIC4, "2029")),
        ((Standards.NACE2, "20.59"), (Standards.ISIC4, "2029")),
        ((Standards.NACE2, "20.6"), (Standards.ISIC4, "203")),
        ((Standards.NACE2, "20.60"), (Standards.ISIC4, "2030")),
        ((Standards.NACE2, "21"), (Standards.ISIC4, "21")),
        ((Standards.NACE2, "21.1"), (Standards.ISIC4, "210")),
        ((Standards.NACE2, "21.10"), (Standards.ISIC4, "2100")),
        ((Standards.NACE2, "21.2"), (Standards.ISIC4, "210")),
        ((Standards.NACE2, "21.20"), (Standards.ISIC4, "2100")),
        ((Standards.NACE2, "22"), (Standards.ISIC4, "22")),
        ((Standards.NACE2, "22.1"), (Standards.ISIC4, "221")),
        ((Standards.NACE2, "22.11"), (Standards.ISIC4, "2211")),
        ((Standards.NACE2, "22.19"), (Standards.ISIC4, "2219")),
        ((Standards.NACE2, "22.2"), (Standards.ISIC4, "222")),
        ((Standards.NACE2, "22.21"), (Standards.ISIC4, "2220")),
        ((Standards.NACE2, "22.22"), (Standards.ISIC4, "2220")),
        ((Standards.NACE2, "22.23"), (Standards.ISIC4, "2220")),
        ((Standards.NACE2, "22.29"), (Standards.ISIC4, "2220")),
        ((Standards.NACE2, "23"), (Standards.ISIC4, "23")),
        ((Standards.NACE2, "23.1"), (Standards.ISIC4, "231")),
        ((Standards.NACE2, "23.11"), (Standards.ISIC4, "2310")),
        ((Standards.NACE2, "23.12"), (Standards.ISIC4, "2310")),
        ((Standards.NACE2, "23.13"), (Standards.ISIC4, "2310")),
        ((Standards.NACE2, "23.14"), (Standards.ISIC4, "2310")),
        ((Standards.NACE2, "23.19"), (Standards.ISIC4, "2310")),
        ((Standards.NACE2, "23.2"), (Standards.ISIC4, "239")),
        ((Standards.NACE2, "23.20"), (Standards.ISIC4, "2391")),
        ((Standards.NACE2, "23.3"), (Standards.ISIC4, "239")),
        ((Standards.NACE2, "23.31"), (Standards.ISIC4, "2392")),
        ((Standards.NACE2, "23.32"), (Standards.ISIC4, "2392")),
        ((Standards.NACE2, "23.4"), (Standards.ISIC4, "239")),
        ((Standards.NACE2, "23.41"), (Standards.ISIC4, "2393")),
        ((Standards.NACE2, "23.42"), (Standards.ISIC4, "2393")),
        ((Standards.NACE2, "23.43"), (Standards.ISIC4, "2393")),
        ((Standards.NACE2, "23.44"), (Standards.ISIC4, "2393")),
        ((Standards.NACE2, "23.49"), (Standards.ISIC4, "2393")),
        ((Standards.NACE2, "23.5"), (Standards.ISIC4, "239")),
        ((Standards.NACE2, "23.51"), (Standards.ISIC4, "2394")),
        ((Standards.NACE2, "23.52"), (Standards.ISIC4, "2394")),
        ((Standards.NACE2, "23.6"), (Standards.ISIC4, "239")),
        ((Standards.NACE2, "23.61"), (Standards.ISIC4, "2395")),
        ((Standards.NACE2, "23.62"), (Standards.ISIC4, "2395")),
        ((Standards.NACE2, "23.63"), (Standards.ISIC4, "2395")),
        ((Standards.NACE2, "23.64"), (Standards.ISIC4, "2395")),
        ((Standards.NACE2, "23.65"), (Standards.ISIC4, "2395")),
        ((Standards.NACE2, "23.69"), (Standards.ISIC4, "2395")),
        ((Standards.NACE2, "23.7"), (Standards.ISIC4, "239")),
        ((Standards.NACE2, "23.70"), (Standards.ISIC4, "2396")),
        ((Standards.NACE2, "23.9"), (Standards.ISIC4, "239")),
        ((Standards.NACE2, "23.91"), (Standards.ISIC4, "2399")),
        ((Standards.NACE2, "23.99"), (Standards.ISIC4, "2399")),
        ((Standards.NACE2, "24"), (Standards.ISIC4, "24")),
        ((Standards.NACE2, "24.1"), (Standards.ISIC4, "241")),
        ((Standards.NACE2, "24.10"), (Standards.ISIC4, "2410")),
        ((Standards.NACE2, "24.2"), (Standards.ISIC4, "241")),
        ((Standards.NACE2, "24.20"), (Standards.ISIC4, "2410")),
        ((Standards.NACE2, "24.3"), (Standards.ISIC4, "241")),
        ((Standards.NACE2, "24.31"), (Standards.ISIC4, "2410")),
        ((Standards.NACE2, "24.32"), (Standards.ISIC4, "2410")),
        ((Standards.NACE2, "24.33"), (Standards.ISIC4, "2410")),
        ((Standards.NACE2, "24.34"), (Standards.ISIC4, "2410")),
        ((Standards.NACE2, "24.4"), (Standards.ISIC4, "242")),
        ((Standards.NACE2, "24.41"), (Standards.ISIC4, "2420")),
        ((Standards.NACE2, "24.42"), (Standards.ISIC4, "2420")),
        ((Standards.NACE2, "24.43"), (Standards.ISIC4, "2420")),
        ((Standards.NACE2, "24.44"), (Standards.ISIC4, "2420")),
        ((Standards.NACE2, "24.45"), (Standards.ISIC4, "2420")),
        ((Standards.NACE2, "24.46"), (Standards.ISIC4, "2420")),
        ((Standards.NACE2, "24.5"), (Standards.ISIC4, "243")),
        ((Standards.NACE2, "24.51"), (Standards.ISIC4, "2431")),
        ((Standards.NACE2, "24.52"), (Standards.ISIC4, "2431")),
        ((Standards.NACE2, "24.53"), (Standards.ISIC4, "2432")),
        ((Standards.NACE2, "24.54"), (Standards.ISIC4, "2432")),
        ((Standards.NACE2, "25"), (Standards.ISIC4, "25")),
        ((Standards.NACE2, "25.1"), (Standards.ISIC4, "251")),
        ((Standards.NACE2, "25.11"), (Standards.ISIC4, "2511")),
        ((Standards.NACE2, "25.12"), (Standards.ISIC4, "2511")),
        ((Standards.NACE2, "25.2"), (Standards.ISIC4, "251")),
        ((Standards.NACE2, "25.21"), (Standards.ISIC4, "2512")),
        ((Standards.NACE2, "25.29"), (Standards.ISIC4, "2512")),
        ((Standards.NACE2, "25.3"), (Standards.ISIC4, "251")),
        ((Standards.NACE2, "25.30"), (Standards.ISIC4, "2513")),
        ((Standards.NACE2, "25.4"), (Standards.ISIC4, "252")),
        ((Standards.NACE2, "25.40"), (Standards.ISIC4, "2520")),
        ((Standards.NACE2, "25.5"), (Standards.ISIC4, "259")),
        ((Standards.NACE2, "25.50"), (Standards.ISIC4, "2591")),
        ((Standards.NACE2, "25.6"), (Standards.ISIC4, "259")),
        ((Standards.NACE2, "25.61"), (Standards.ISIC4, "2592")),
        ((Standards.NACE2, "25.62"), (Standards.ISIC4, "2592")),
        ((Standards.NACE2, "25.7"), (Standards.ISIC4, "259")),
        ((Standards.NACE2, "25.71"), (Standards.ISIC4, "2593")),
        ((Standards.NACE2, "25.72"), (Standards.ISIC4, "2593")),
        ((Standards.NACE2, "25.73"), (Standards.ISIC4, "2593")),
        ((Standards.NACE2, "25.9"), (Standards.ISIC4, "259")),
        ((Standards.NACE2, "25.91"), (Standards.ISIC4, "2599")),
        ((Standards.NACE2, "25.92"), (Standards.ISIC4, "2599")),
        ((Standards.NACE2, "25.93"), (Standards.ISIC4, "2599")),
        ((Standards.NACE2, "25.94"), (Standards.ISIC4, "2599")),
        ((Standards.NACE2, "25.99"), (Standards.ISIC4, "2599")),
        ((Standards.NACE2, "26"), (Standards.ISIC4, "26")),
        ((Standards.NACE2, "26.1"), (Standards.ISIC4, "261")),
        ((Standards.NACE2, "26.11"), (Standards.ISIC4, "2610")),
        ((Standards.NACE2, "26.12"), (Standards.ISIC4, "2610")),
        ((Standards.NACE2, "26.2"), (Standards.ISIC4, "262")),
        ((Standards.NACE2, "26.20"), (Standards.ISIC4, "2620")),
        ((Standards.NACE2, "26.3"), (Standards.ISIC4, "263")),
        ((Standards.NACE2, "26.30"), (Standards.ISIC4, "2630")),
        ((Standards.NACE2, "26.4"), (Standards.ISIC4, "264")),
        ((Standards.NACE2, "26.40"), (Standards.ISIC4, "2640")),
        ((Standards.NACE2, "26.5"), (Standards.ISIC4, "265")),
        ((Standards.NACE2, "26.51"), (Standards.ISIC4, "2651")),
        ((Standards.NACE2, "26.52"), (Standards.ISIC4, "2652")),
        ((Standards.NACE2, "26.6"), (Standards.ISIC4, "266")),
        ((Standards.NACE2, "26.60"), (Standards.ISIC4, "2660")),
        ((Standards.NACE2, "26.7"), (Standards.ISIC4, "267")),
        ((Standards.NACE2, "26.70"), (Standards.ISIC4, "2670")),
        ((Standards.NACE2, "26.8"), (Standards.ISIC4, "268")),
        ((Standards.NACE2, "26.80"), (Standards.ISIC4, "2680")),
        ((Standards.NACE2, "27"), (Standards.ISIC4, "27")),
        ((Standards.NACE2, "27.1"), (Standards.ISIC4, "271")),
        ((Standards.NACE2, "27.11"), (Standards.ISIC4, "2710")),
        ((Standards.NACE2, "27.12"), (Standards.ISIC4, "2710")),
        ((Standards.NACE2, "27.2"), (Standards.ISIC4, "272")),
        ((Standards.NACE2, "27.20"), (Standards.ISIC4, "2720")),
        ((Standards.NACE2, "27.3"), (Standards.ISIC4, "273")),
        ((Standards.NACE2, "27.31"), (Standards.ISIC4, "2731")),
        ((Standards.NACE2, "27.32"), (Standards.ISIC4, "2732")),
        ((Standards.NACE2, "27.33"), (Standards.ISIC4, "2733")),
        ((Standards.NACE2, "27.4"), (Standards.ISIC4, "274")),
        ((Standards.NACE2, "27.40"), (Standards.ISIC4, "2740")),
        ((Standards.NACE2, "27.5"), (Standards.ISIC4, "275")),
        ((Standards.NACE2, "27.51"), (Standards.ISIC4, "2750")),
        ((Standards.NACE2, "27.52"), (Standards.ISIC4, "2750")),
        ((Standards.NACE2, "27.9"), (Standards.ISIC4, "279")),
        ((Standards.NACE2, "27.90"), (Standards.ISIC4, "2790")),
        ((Standards.NACE2, "28"), (Standards.ISIC4, "28")),
        ((Standards.NACE2, "28.1"), (Standards.ISIC4, "281")),
        ((Standards.NACE2, "28.11"), (Standards.ISIC4, "2811")),
        ((Standards.NACE2, "28.12"), (Standards.ISIC4, "2812")),
        ((Standards.NACE2, "28.13"), (Standards.ISIC4, "2813")),
        ((Standards.NACE2, "28.14"), (Standards.ISIC4, "2813")),
        ((Standards.NACE2, "28.15"), (Standards.ISIC4, "2814")),
        ((Standards.NACE2, "28.2"), (Standards.ISIC4, "281")),
        ((Standards.NACE2, "28.21"), (Standards.ISIC4, "2815")),
        ((Standards.NACE2, "28.22"), (Standards.ISIC4, "2816")),
        ((Standards.NACE2, "28.23"), (Standards.ISIC4, "2817")),
        ((Standards.NACE2, "28.24"), (Standards.ISIC4, "2818")),
        ((Standards.NACE2, "28.25"), (Standards.ISIC4, "2819")),
        ((Standards.NACE2, "28.29"), (Standards.ISIC4, "2819")),
        ((Standards.NACE2, "28.3"), (Standards.ISIC4, "282")),
        ((Standards.NACE2, "28.30"), (Standards.ISIC4, "2821")),
        ((Standards.NACE2, "28.4"), (Standards.ISIC4, "282")),
        ((Standards.NACE2, "28.41"), (Standards.ISIC4, "2822")),
        ((Standards.NACE2, "28.49"), (Standards.ISIC4, "2822")),
        ((Standards.NACE2, "28.9"), (Standards.ISIC4, "282")),
        ((Standards.NACE2, "28.91"), (Standards.ISIC4, "2823")),
        ((Standards.NACE2, "28.92"), (Standards.ISIC4, "2824")),
        ((Standards.NACE2, "28.93"), (Standards.ISIC4, "2825")),
        ((Standards.NACE2, "28.94"), (Standards.ISIC4, "2826")),
        ((Standards.NACE2, "28.95"), (Standards.ISIC4, "2829")),
        ((Standards.NACE2, "28.96"), (Standards.ISIC4, "2829")),
        ((Standards.NACE2, "28.99"), (Standards.ISIC4, "2829")),
        ((Standards.NACE2, "29"), (Standards.ISIC4, "29")),
        ((Standards.NACE2, "29.1"), (Standards.ISIC4, "291")),
        ((Standards.NACE2, "29.10"), (Standards.ISIC4, "2910")),
        ((Standards.NACE2, "29.2"), (Standards.ISIC4, "292")),
        ((Standards.NACE2, "29.20"), (Standards.ISIC4, "2920")),
        ((Standards.NACE2, "29.3"), (Standards.ISIC4, "293")),
        ((Standards.NACE2, "29.31"), (Standards.ISIC4, "2930")),
        ((Standards.NACE2, "29.32"), (Standards.ISIC4, "2930")),
        ((Standards.NACE2, "30"), (Standards.ISIC4, "30")),
        ((Standards.NACE2, "30.1"), (Standards.ISIC4, "301")),
        ((Standards.NACE2, "30.11"), (Standards.ISIC4, "3011")),
        ((Standards.NACE2, "30.12"), (Standards.ISIC4, "3012")),
        ((Standards.NACE2, "30.2"), (Standards.ISIC4, "302")),
        ((Standards.NACE2, "30.20"), (Standards.ISIC4, "3020")),
        ((Standards.NACE2, "30.3"), (Standards.ISIC4, "303")),
        ((Standards.NACE2, "30.30"), (Standards.ISIC4, "3030")),
        ((Standards.NACE2, "30.4"), (Standards.ISIC4, "304")),
        ((Standards.NACE2, "30.40"), (Standards.ISIC4, "3040")),
        ((Standards.NACE2, "30.9"), (Standards.ISIC4, "309")),
        ((Standards.NACE2, "30.91"), (Standards.ISIC4, "3091")),
        ((Standards.NACE2, "30.92"), (Standards.ISIC4, "3092")),
        ((Standards.NACE2, "30.99"), (Standards.ISIC4, "3099")),
        ((Standards.NACE2, "31"), (Standards.ISIC4, "31")),
        ((Standards.NACE2, "31.0"), (Standards.ISIC4, "310")),
        ((Standards.NACE2, "31.01"), (Standards.ISIC4, "3100")),
        ((Standards.NACE2, "31.02"), (Standards.ISIC4, "3100")),
        ((Standards.NACE2, "31.03"), (Standards.ISIC4, "3100")),
        ((Standards.NACE2, "31.09"), (Standards.ISIC4, "3100")),
        ((Standards.NACE2, "32"), (Standards.ISIC4, "32")),
        ((Standards.NACE2, "32.1"), (Standards.ISIC4, "321")),
        ((Standards.NACE2, "32.11"), (Standards.ISIC4, "3211")),
        ((Standards.NACE2, "32.12"), (Standards.ISIC4, "3211")),
        ((Standards.NACE2, "32.13"), (Standards.ISIC4, "3212")),
        ((Standards.NACE2, "32.2"), (Standards.ISIC4, "322")),
        ((Standards.NACE2, "32.20"), (Standards.ISIC4, "3220")),
        ((Standards.NACE2, "32.3"), (Standards.ISIC4, "323")),
        ((Standards.NACE2, "32.30"), (Standards.ISIC4, "3230")),
        ((Standards.NACE2, "32.4"), (Standards.ISIC4, "324")),
        ((Standards.NACE2, "32.40"), (Standards.ISIC4, "3240")),
        ((Standards.NACE2, "32.5"), (Standards.ISIC4, "325")),
        ((Standards.NACE2, "32.50"), (Standards.ISIC4, "3250")),
        ((Standards.NACE2, "32.9"), (Standards.ISIC4, "329")),
        ((Standards.NACE2, "32.91"), (Standards.ISIC4, "3290")),
        ((Standards.NACE2, "32.99"), (Standards.ISIC4, "3290")),
        ((Standards.NACE2, "33"), (Standards.ISIC4, "33")),
        ((Standards.NACE2, "33.1"), (Standards.ISIC4, "331")),
        ((Standards.NACE2, "33.11"), (Standards.ISIC4, "3311")),
        ((Standards.NACE2, "33.12"), (Standards.ISIC4, "3312")),
        ((Standards.NACE2, "33.13"), (Standards.ISIC4, "3313")),
        ((Standards.NACE2, "33.14"), (Standards.ISIC4, "3314")),
        ((Standards.NACE2, "33.15"), (Standards.ISIC4, "3315")),
        ((Standards.NACE2, "33.16"), (Standards.ISIC4, "3315")),
        ((Standards.NACE2, "33.17"), (Standards.ISIC4, "3315")),
        ((Standards.NACE2, "33.19"), (Standards.ISIC4, "3319")),
        ((Standards.NACE2, "33.2"), (Standards.ISIC4, "332")),
        ((Standards.NACE2, "33.20"), (Standards.ISIC4, "3320")),
        ((Standards.NACE2, "D"), (Standards.ISIC4, "D")),
        ((Standards.NACE2, "35"), (Standards.ISIC4, "35")),
        ((Standards.NACE2, "35.1"), (Standards.ISIC4, "351")),
        ((Standards.NACE2, "35.11"), (Standards.ISIC4, "3510")),
        ((Standards.NACE2, "35.12"), (Standards.ISIC4, "3510")),
        ((Standards.NACE2, "35.13"), (Standards.ISIC4, "3510")),
        ((Standards.NACE2, "35.14"), (Standards.ISIC4, "3510")),
        ((Standards.NACE2, "35.2"), (Standards.ISIC4, "352")),
        ((Standards.NACE2, "35.21"), (Standards.ISIC4, "3520")),
        ((Standards.NACE2, "35.22"), (Standards.ISIC4, "3520")),
        ((Standards.NACE2, "35.23"), (Standards.ISIC4, "3520")),
        ((Standards.NACE2, "35.3"), (Standards.ISIC4, "353")),
        ((Standards.NACE2, "35.30"), (Standards.ISIC4, "3530")),
        ((Standards.NACE2, "E"), (Standards.ISIC4, "E")),
        ((Standards.NACE2, "36"), (Standards.ISIC4, "36")),
        ((Standards.NACE2, "36.0"), (Standards.ISIC4, "360")),
        ((Standards.NACE2, "36.00"), (Standards.ISIC4, "3600")),
        ((Standards.NACE2, "37"), (Standards.ISIC4, "37")),
        ((Standards.NACE2, "37.0"), (Standards.ISIC4, "370")),
        ((Standards.NACE2, "37.00"), (Standards.ISIC4, "3700")),
        ((Standards.NACE2, "38"), (Standards.ISIC4, "38")),
        ((Standards.NACE2, "38.1"), (Standards.ISIC4, "381")),
        ((Standards.NACE2, "38.11"), (Standards.ISIC4, "3811")),
        ((Standards.NACE2, "38.12"), (Standards.ISIC4, "3812")),
        ((Standards.NACE2, "38.2"), (Standards.ISIC4, "382")),
        ((Standards.NACE2, "38.21"), (Standards.ISIC4, "3821")),
        ((Standards.NACE2, "38.22"), (Standards.ISIC4, "3822")),
        ((Standards.NACE2, "38.3"), (Standards.ISIC4, "383")),
        ((Standards.NACE2, "38.31"), (Standards.ISIC4, "3830")),
        ((Standards.NACE2, "38.32"), (Standards.ISIC4, "3830")),
        ((Standards.NACE2, "39"), (Standards.ISIC4, "39")),
        ((Standards.NACE2, "39.0"), (Standards.ISIC4, "390")),
        ((Standards.NACE2, "39.00"), (Standards.ISIC4, "3900")),
        ((Standards.NACE2, "F"), (Standards.ISIC4, "F")),
        ((Standards.NACE2, "41"), (Standards.ISIC4, "41")),
        ((Standards.NACE2, "41.1"), (Standards.ISIC4, "410")),
        ((Standards.NACE2, "41.10"), (Standards.ISIC4, "4100")),
        ((Standards.NACE2, "41.2"), (Standards.ISIC4, "410")),
        ((Standards.NACE2, "41.20"), (Standards.ISIC4, "4100")),
        ((Standards.NACE2, "42"), (Standards.ISIC4, "42")),
        ((Standards.NACE2, "42.1"), (Standards.ISIC4, "421")),
        ((Standards.NACE2, "42.11"), (Standards.ISIC4, "4210")),
        ((Standards.NACE2, "42.12"), (Standards.ISIC4, "4210")),
        ((Standards.NACE2, "42.13"), (Standards.ISIC4, "4210")),
        ((Standards.NACE2, "42.2"), (Standards.ISIC4, "422")),
        ((Standards.NACE2, "42.21"), (Standards.ISIC4, "4220")),
        ((Standards.NACE2, "42.22"), (Standards.ISIC4, "4220")),
        ((Standards.NACE2, "42.9"), (Standards.ISIC4, "429")),
        ((Standards.NACE2, "42.91"), (Standards.ISIC4, "4290")),
        ((Standards.NACE2, "42.99"), (Standards.ISIC4, "4290")),
        ((Standards.NACE2, "43"), (Standards.ISIC4, "43")),
        ((Standards.NACE2, "43.1"), (Standards.ISIC4, "431")),
        ((Standards.NACE2, "43.11"), (Standards.ISIC4, "4311")),
        ((Standards.NACE2, "43.12"), (Standards.ISIC4, "4312")),
        ((Standards.NACE2, "43.13"), (Standards.ISIC4, "4312")),
        ((Standards.NACE2, "43.2"), (Standards.ISIC4, "432")),
        ((Standards.NACE2, "43.21"), (Standards.ISIC4, "4321")),
        ((Standards.NACE2, "43.22"), (Standards.ISIC4, "4322")),
        ((Standards.NACE2, "43.29"), (Standards.ISIC4, "4329")),
        ((Standards.NACE2, "43.3"), (Standards.ISIC4, "433")),
        ((Standards.NACE2, "43.31"), (Standards.ISIC4, "4330")),
        ((Standards.NACE2, "43.32"), (Standards.ISIC4, "4330")),
        ((Standards.NACE2, "43.33"), (Standards.ISIC4, "4330")),
        ((Standards.NACE2, "43.34"), (Standards.ISIC4, "4330")),
        ((Standards.NACE2, "43.39"), (Standards.ISIC4, "4330")),
        ((Standards.NACE2, "43.9"), (Standards.ISIC4, "439")),
        ((Standards.NACE2, "43.91"), (Standards.ISIC4, "4390")),
        ((Standards.NACE2, "43.99"), (Standards.ISIC4, "4390")),
        ((Standards.NACE2, "G"), (Standards.ISIC4, "G")),
        ((Standards.NACE2, "45"), (Standards.ISIC4, "45")),
        ((Standards.NACE2, "45.1"), (Standards.ISIC4, "451")),
        ((Standards.NACE2, "45.11"), (Standards.ISIC4, "4510")),
        ((Standards.NACE2, "45.19"), (Standards.ISIC4, "4510")),
        ((Standards.NACE2, "45.2"), (Standards.ISIC4, "452")),
        ((Standards.NACE2, "45.20"), (Standards.ISIC4, "4520")),
        ((Standards.NACE2, "45.3"), (Standards.ISIC4, "453")),
        ((Standards.NACE2, "45.31"), (Standards.ISIC4, "4530")),
        ((Standards.NACE2, "45.32"), (Standards.ISIC4, "4530")),
        ((Standards.NACE2, "45.4"), (Standards.ISIC4, "454")),
        ((Standards.NACE2, "45.40"), (Standards.ISIC4, "4540")),
        ((Standards.NACE2, "46"), (Standards.ISIC4, "46")),
        ((Standards.NACE2, "46.1"), (Standards.ISIC4, "461")),
        ((Standards.NACE2, "46.11"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.12"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.13"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.14"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.15"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.16"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.17"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.18"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.19"), (Standards.ISIC4, "4610")),
        ((Standards.NACE2, "46.2"), (Standards.ISIC4, "462")),
        ((Standards.NACE2, "46.21"), (Standards.ISIC4, "4620")),
        ((Standards.NACE2, "46.22"), (Standards.ISIC4, "4620")),
        ((Standards.NACE2, "46.23"), (Standards.ISIC4, "4620")),
        ((Standards.NACE2, "46.24"), (Standards.ISIC4, "4620")),
        ((Standards.NACE2, "46.3"), (Standards.ISIC4, "463")),
        ((Standards.NACE2, "46.31"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.32"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.33"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.34"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.35"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.36"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.37"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.38"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.39"), (Standards.ISIC4, "4630")),
        ((Standards.NACE2, "46.4"), (Standards.ISIC4, "464")),
        ((Standards.NACE2, "46.41"), (Standards.ISIC4, "4641")),
        ((Standards.NACE2, "46.42"), (Standards.ISIC4, "4641")),
        ((Standards.NACE2, "46.43"), (Standards.ISIC4, "4649")),
        ((Standards.NACE2, "46.44"), (Standards.ISIC4, "4649")),
        ((Standards.NACE2, "46.45"), (Standards.ISIC4, "4649")),
        ((Standards.NACE2, "46.46"), (Standards.ISIC4, "4649")),
        ((Standards.NACE2, "46.47"), (Standards.ISIC4, "4649")),
        ((Standards.NACE2, "46.48"), (Standards.ISIC4, "4649")),
        ((Standards.NACE2, "46.49"), (Standards.ISIC4, "4649")),
        ((Standards.NACE2, "46.5"), (Standards.ISIC4, "465")),
        ((Standards.NACE2, "46.51"), (Standards.ISIC4, "4651")),
        ((Standards.NACE2, "46.52"), (Standards.ISIC4, "4652")),
        ((Standards.NACE2, "46.6"), (Standards.ISIC4, "466")),
        ((Standards.NACE2, "46.61"), (Standards.ISIC4, "4653")),
        ((Standards.NACE2, "46.62"), (Standards.ISIC4, "4659")),
        ((Standards.NACE2, "46.63"), (Standards.ISIC4, "4659")),
        ((Standards.NACE2, "46.64"), (Standards.ISIC4, "4659")),
        ((Standards.NACE2, "46.65"), (Standards.ISIC4, "4659")),
        ((Standards.NACE2, "46.66"), (Standards.ISIC4, "4659")),
        ((Standards.NACE2, "46.69"), (Standards.ISIC4, "4659")),
        ((Standards.NACE2, "46.7"), (Standards.ISIC4, "466")),
        ((Standards.NACE2, "46.71"), (Standards.ISIC4, "4661")),
        ((Standards.NACE2, "46.72"), (Standards.ISIC4, "4662")),
        ((Standards.NACE2, "46.73"), (Standards.ISIC4, "4663")),
        ((Standards.NACE2, "46.74"), (Standards.ISIC4, "4663")),
        ((Standards.NACE2, "46.75"), (Standards.ISIC4, "4669")),
        ((Standards.NACE2, "46.76"), (Standards.ISIC4, "4669")),
        ((Standards.NACE2, "46.77"), (Standards.ISIC4, "4669")),
        ((Standards.NACE2, "46.9"), (Standards.ISIC4, "469")),
        ((Standards.NACE2, "46.90"), (Standards.ISIC4, "4690")),
        ((Standards.NACE2, "47"), (Standards.ISIC4, "47")),
        ((Standards.NACE2, "47.1"), (Standards.ISIC4, "471")),
        ((Standards.NACE2, "47.11"), (Standards.ISIC4, "4711")),
        ((Standards.NACE2, "47.19"), (Standards.ISIC4, "4719")),
        ((Standards.NACE2, "47.2"), (Standards.ISIC4, "472")),
        ((Standards.NACE2, "47.21"), (Standards.ISIC4, "4721")),
        ((Standards.NACE2, "47.22"), (Standards.ISIC4, "4721")),
        ((Standards.NACE2, "47.23"), (Standards.ISIC4, "4721")),
        ((Standards.NACE2, "47.24"), (Standards.ISIC4, "4721")),
        ((Standards.NACE2, "47.25"), (Standards.ISIC4, "4722")),
        ((Standards.NACE2, "47.26"), (Standards.ISIC4, "4723")),
        ((Standards.NACE2, "47.29"), (Standards.ISIC4, "4721")),
        ((Standards.NACE2, "47.3"), (Standards.ISIC4, "473")),
        ((Standards.NACE2, "47.30"), (Standards.ISIC4, "4730")),
        ((Standards.NACE2, "47.4"), (Standards.ISIC4, "474")),
        ((Standards.NACE2, "47.41"), (Standards.ISIC4, "4741")),
        ((Standards.NACE2, "47.42"), (Standards.ISIC4, "4741")),
        ((Standards.NACE2, "47.43"), (Standards.ISIC4, "4742")),
        ((Standards.NACE2, "47.5"), (Standards.ISIC4, "475")),
        ((Standards.NACE2, "47.51"), (Standards.ISIC4, "4751")),
        ((Standards.NACE2, "47.52"), (Standards.ISIC4, "4752")),
        ((Standards.NACE2, "47.53"), (Standards.ISIC4, "4753")),
        ((Standards.NACE2, "47.54"), (Standards.ISIC4, "4759")),
        ((Standards.NACE2, "47.59"), (Standards.ISIC4, "4759")),
        ((Standards.NACE2, "47.6"), (Standards.ISIC4, "476")),
        ((Standards.NACE2, "47.61"), (Standards.ISIC4, "4761")),
        ((Standards.NACE2, "47.62"), (Standards.ISIC4, "4761")),
        ((Standards.NACE2, "47.63"), (Standards.ISIC4, "4762")),
        ((Standards.NACE2, "47.64"), (Standards.ISIC4, "4763")),
        ((Standards.NACE2, "47.65"), (Standards.ISIC4, "4764")),
        ((Standards.NACE2, "47.7"), (Standards.ISIC4, "477")),
        ((Standards.NACE2, "47.71"), (Standards.ISIC4, "4771")),
        ((Standards.NACE2, "47.72"), (Standards.ISIC4, "4771")),
        ((Standards.NACE2, "47.73"), (Standards.ISIC4, "4772")),
        ((Standards.NACE2, "47.74"), (Standards.ISIC4, "4772")),
        ((Standards.NACE2, "47.75"), (Standards.ISIC4, "4772")),
        ((Standards.NACE2, "47.76"), (Standards.ISIC4, "4773")),
        ((Standards.NACE2, "47.77"), (Standards.ISIC4, "4773")),
        ((Standards.NACE2, "47.78"), (Standards.ISIC4, "4773")),
        ((Standards.NACE2, "47.79"), (Standards.ISIC4, "4774")),
        ((Standards.NACE2, "47.8"), (Standards.ISIC4, "478")),
        ((Standards.NACE2, "47.81"), (Standards.ISIC4, "4781")),
        ((Standards.NACE2, "47.82"), (Standards.ISIC4, "4782")),
        ((Standards.NACE2, "47.89"), (Standards.ISIC4, "4789")),
        ((Standards.NACE2, "47.9"), (Standards.ISIC4, "479")),
        ((Standards.NACE2, "47.91"), (Standards.ISIC4, "4791")),
        ((Standards.NACE2, "47.99"), (Standards.ISIC4, "4799")),
        ((Standards.NACE2, "H"), (Standards.ISIC4, "H")),
        ((Standards.NACE2, "49"), (Standards.ISIC4, "49")),
        ((Standards.NACE2, "49.1"), (Standards.ISIC4, "491")),
        ((Standards.NACE2, "49.10"), (Standards.ISIC4, "4911")),
        ((Standards.NACE2, "49.2"), (Standards.ISIC4, "491")),
        ((Standards.NACE2, "49.20"), (Standards.ISIC4, "4912")),
        ((Standards.NACE2, "49.3"), (Standards.ISIC4, "492")),
        ((Standards.NACE2, "49.31"), (Standards.ISIC4, "4921")),
        ((Standards.NACE2, "49.32"), (Standards.ISIC4, "4922")),
        ((Standards.NACE2, "49.39"), (Standards.ISIC4, "4922")),
        ((Standards.NACE2, "49.4"), (Standards.ISIC4, "492")),
        ((Standards.NACE2, "49.41"), (Standards.ISIC4, "4923")),
        ((Standards.NACE2, "49.42"), (Standards.ISIC4, "4923")),
        ((Standards.NACE2, "49.5"), (Standards.ISIC4, "493")),
        ((Standards.NACE2, "49.50"), (Standards.ISIC4, "4930")),
        ((Standards.NACE2, "50"), (Standards.ISIC4, "50")),
        ((Standards.NACE2, "50.1"), (Standards.ISIC4, "501")),
        ((Standards.NACE2, "50.10"), (Standards.ISIC4, "5011")),
        ((Standards.NACE2, "50.2"), (Standards.ISIC4, "501")),
        ((Standards.NACE2, "50.20"), (Standards.ISIC4, "5012")),
        ((Standards.NACE2, "50.3"), (Standards.ISIC4, "502")),
        ((Standards.NACE2, "50.30"), (Standards.ISIC4, "5021")),
        ((Standards.NACE2, "50.4"), (Standards.ISIC4, "502")),
        ((Standards.NACE2, "50.40"), (Standards.ISIC4, "5022")),
        ((Standards.NACE2, "51"), (Standards.ISIC4, "51")),
        ((Standards.NACE2, "51.1"), (Standards.ISIC4, "511")),
        ((Standards.NACE2, "51.10"), (Standards.ISIC4, "5110")),
        ((Standards.NACE2, "51.2"), (Standards.ISIC4, "512")),
        ((Standards.NACE2, "51.21"), (Standards.ISIC4, "5120")),
        ((Standards.NACE2, "51.22"), (Standards.ISIC4, "5120")),
        ((Standards.NACE2, "52"), (Standards.ISIC4, "52")),
        ((Standards.NACE2, "52.1"), (Standards.ISIC4, "521")),
        ((Standards.NACE2, "52.10"), (Standards.ISIC4, "5210")),
        ((Standards.NACE2, "52.2"), (Standards.ISIC4, "522")),
        ((Standards.NACE2, "52.21"), (Standards.ISIC4, "5221")),
        ((Standards.NACE2, "52.22"), (Standards.ISIC4, "5222")),
        ((Standards.NACE2, "52.23"), (Standards.ISIC4, "5223")),
        ((Standards.NACE2, "52.24"), (Standards.ISIC4, "5224")),
        ((Standards.NACE2, "52.29"), (Standards.ISIC4, "5229")),
        ((Standards.NACE2, "53"), (Standards.ISIC4, "53")),
        ((Standards.NACE2, "53.1"), (Standards.ISIC4, "531")),
        ((Standards.NACE2, "53.10"), (Standards.ISIC4, "5310")),
        ((Standards.NACE2, "53.2"), (Standards.ISIC4, "532")),
        ((Standards.NACE2, "53.20"), (Standards.ISIC4, "5320")),
        ((Standards.NACE2, "I"), (Standards.ISIC4, "I")),
        ((Standards.NACE2, "55"), (Standards.ISIC4, "55")),
        ((Standards.NACE2, "55.1"), (Standards.ISIC4, "551")),
        ((Standards.NACE2, "55.10"), (Standards.ISIC4, "5510")),
        ((Standards.NACE2, "55.2"), (Standards.ISIC4, "551")),
        ((Standards.NACE2, "55.20"), (Standards.ISIC4, "5510")),
        ((Standards.NACE2, "55.3"), (Standards.ISIC4, "552")),
        ((Standards.NACE2, "55.30"), (Standards.ISIC4, "5520")),
        ((Standards.NACE2, "55.9"), (Standards.ISIC4, "559")),
        ((Standards.NACE2, "55.90"), (Standards.ISIC4, "5590")),
        ((Standards.NACE2, "56"), (Standards.ISIC4, "56")),
        ((Standards.NACE2, "56.1"), (Standards.ISIC4, "561")),
        ((Standards.NACE2, "56.10"), (Standards.ISIC4, "5610")),
        ((Standards.NACE2, "56.2"), (Standards.ISIC4, "562")),
        ((Standards.NACE2, "56.21"), (Standards.ISIC4, "5621")),
        ((Standards.NACE2, "56.29"), (Standards.ISIC4, "5629")),
        ((Standards.NACE2, "56.3"), (Standards.ISIC4, "563")),
        ((Standards.NACE2, "56.30"), (Standards.ISIC4, "5630")),
        ((Standards.NACE2, "J"), (Standards.ISIC4, "J")),
        ((Standards.NACE2, "58"), (Standards.ISIC4, "58")),
        ((Standards.NACE2, "58.1"), (Standards.ISIC4, "581")),
        ((Standards.NACE2, "58.11"), (Standards.ISIC4, "5811")),
        ((Standards.NACE2, "58.12"), (Standards.ISIC4, "5812")),
        ((Standards.NACE2, "58.13"), (Standards.ISIC4, "5813")),
        ((Standards.NACE2, "58.14"), (Standards.ISIC4, "5813")),
        ((Standards.NACE2, "58.19"), (Standards.ISIC4, "5819")),
        ((Standards.NACE2, "58.2"), (Standards.ISIC4, "582")),
        ((Standards.NACE2, "58.21"), (Standards.ISIC4, "5820")),
        ((Standards.NACE2, "58.29"), (Standards.ISIC4, "5820")),
        ((Standards.NACE2, "59"), (Standards.ISIC4, "59")),
        ((Standards.NACE2, "59.1"), (Standards.ISIC4, "591")),
        ((Standards.NACE2, "59.11"), (Standards.ISIC4, "5911")),
        ((Standards.NACE2, "59.12"), (Standards.ISIC4, "5912")),
        ((Standards.NACE2, "59.13"), (Standards.ISIC4, "5913")),
        ((Standards.NACE2, "59.14"), (Standards.ISIC4, "5914")),
        ((Standards.NACE2, "59.2"), (Standards.ISIC4, "592")),
        ((Standards.NACE2, "59.20"), (Standards.ISIC4, "5920")),
        ((Standards.NACE2, "60"), (Standards.ISIC4, "60")),
        ((Standards.NACE2, "60.1"), (Standards.ISIC4, "601")),
        ((Standards.NACE2, "60.10"), (Standards.ISIC4, "6010")),
        ((Standards.NACE2, "60.2"), (Standards.ISIC4, "602")),
        ((Standards.NACE2, "60.20"), (Standards.ISIC4, "6020")),
        ((Standards.NACE2, "61"), (Standards.ISIC4, "61")),
        ((Standards.NACE2, "61.1"), (Standards.ISIC4, "611")),
        ((Standards.NACE2, "61.10"), (Standards.ISIC4, "6110")),
        ((Standards.NACE2, "61.2"), (Standards.ISIC4, "612")),
        ((Standards.NACE2, "61.20"), (Standards.ISIC4, "6120")),
        ((Standards.NACE2, "61.3"), (Standards.ISIC4, "613")),
        ((Standards.NACE2, "61.30"), (Standards.ISIC4, "6130")),
        ((Standards.NACE2, "61.9"), (Standards.ISIC4, "619")),
        ((Standards.NACE2, "61.90"), (Standards.ISIC4, "6190")),
        ((Standards.NACE2, "62"), (Standards.ISIC4, "62")),
        ((Standards.NACE2, "62.0"), (Standards.ISIC4, "620")),
        ((Standards.NACE2, "62.01"), (Standards.ISIC4, "6201")),
        ((Standards.NACE2, "62.02"), (Standards.ISIC4, "6202")),
        ((Standards.NACE2, "62.03"), (Standards.ISIC4, "6202")),
        ((Standards.NACE2, "62.09"), (Standards.ISIC4, "6209")),
        ((Standards.NACE2, "63"), (Standards.ISIC4, "63")),
        ((Standards.NACE2, "63.1"), (Standards.ISIC4, "631")),
        ((Standards.NACE2, "63.11"), (Standards.ISIC4, "6311")),
        ((Standards.NACE2, "63.12"), (Standards.ISIC4, "6312")),
        ((Standards.NACE2, "63.9"), (Standards.ISIC4, "639")),
        ((Standards.NACE2, "63.91"), (Standards.ISIC4, "6391")),
        ((Standards.NACE2, "63.99"), (Standards.ISIC4, "6399")),
        ((Standards.NACE2, "K"), (Standards.ISIC4, "K")),
        ((Standards.NACE2, "64"), (Standards.ISIC4, "64")),
        ((Standards.NACE2, "64.1"), (Standards.ISIC4, "641")),
        ((Standards.NACE2, "64.11"), (Standards.ISIC4, "6411")),
        ((Standards.NACE2, "64.19"), (Standards.ISIC4, "6419")),
        ((Standards.NACE2, "64.2"), (Standards.ISIC4, "642")),
        ((Standards.NACE2, "64.20"), (Standards.ISIC4, "6420")),
        ((Standards.NACE2, "64.3"), (Standards.ISIC4, "643")),
        ((Standards.NACE2, "64.30"), (Standards.ISIC4, "6430")),
        ((Standards.NACE2, "64.9"), (Standards.ISIC4, "649")),
        ((Standards.NACE2, "64.91"), (Standards.ISIC4, "6491")),
        ((Standards.NACE2, "64.92"), (Standards.ISIC4, "6492")),
        ((Standards.NACE2, "64.99"), (Standards.ISIC4, "6499")),
        ((Standards.NACE2, "65"), (Standards.ISIC4, "65")),
        ((Standards.NACE2, "65.1"), (Standards.ISIC4, "651")),
        ((Standards.NACE2, "65.11"), (Standards.ISIC4, "6511")),
        ((Standards.NACE2, "65.12"), (Standards.ISIC4, "6512")),
        ((Standards.NACE2, "65.2"), (Standards.ISIC4, "652")),
        ((Standards.NACE2, "65.20"), (Standards.ISIC4, "6520")),
        ((Standards.NACE2, "65.3"), (Standards.ISIC4, "653")),
        ((Standards.NACE2, "65.30"), (Standards.ISIC4, "6530")),
        ((Standards.NACE2, "66"), (Standards.ISIC4, "66")),
        ((Standards.NACE2, "66.1"), (Standards.ISIC4, "661")),
        ((Standards.NACE2, "66.11"), (Standards.ISIC4, "6611")),
        ((Standards.NACE2, "66.12"), (Standards.ISIC4, "6612")),
        ((Standards.NACE2, "66.19"), (Standards.ISIC4, "6619")),
        ((Standards.NACE2, "66.2"), (Standards.ISIC4, "662")),
        ((Standards.NACE2, "66.21"), (Standards.ISIC4, "6621")),
        ((Standards.NACE2, "66.22"), (Standards.ISIC4, "6622")),
        ((Standards.NACE2, "66.29"), (Standards.ISIC4, "6629")),
        ((Standards.NACE2, "66.3"), (Standards.ISIC4, "663")),
        ((Standards.NACE2, "66.30"), (Standards.ISIC4, "6630")),
        ((Standards.NACE2, "L"), (Standards.ISIC4, "L")),
        ((Standards.NACE2, "68"), (Standards.ISIC4, "68")),
        ((Standards.NACE2, "68.1"), (Standards.ISIC4, "681")),
        ((Standards.NACE2, "68.10"), (Standards.ISIC4, "6810")),
        ((Standards.NACE2, "68.2"), (Standards.ISIC4, "681")),
        ((Standards.NACE2, "68.20"), (Standards.ISIC4, "6810")),
        ((Standards.NACE2, "68.3"), (Standards.ISIC4, "682")),
        ((Standards.NACE2, "68.31"), (Standards.ISIC4, "6820")),
        ((Standards.NACE2, "68.32"), (Standards.ISIC4, "6820")),
        ((Standards.NACE2, "M"), (Standards.ISIC4, "M")),
        ((Standards.NACE2, "69"), (Standards.ISIC4, "69")),
        ((Standards.NACE2, "69.1"), (Standards.ISIC4, "691")),
        ((Standards.NACE2, "69.10"), (Standards.ISIC4, "6910")),
        ((Standards.NACE2, "69.2"), (Standards.ISIC4, "692")),
        ((Standards.NACE2, "69.20"), (Standards.ISIC4, "6920")),
        ((Standards.NACE2, "70"), (Standards.ISIC4, "70")),
        ((Standards.NACE2, "70.1"), (Standards.ISIC4, "701")),
        ((Standards.NACE2, "70.10"), (Standards.ISIC4, "7010")),
        ((Standards.NACE2, "70.2"), (Standards.ISIC4, "702")),
        ((Standards.NACE2, "70.21"), (Standards.ISIC4, "7020")),
        ((Standards.NACE2, "70.22"), (Standards.ISIC4, "7020")),
        ((Standards.NACE2, "71"), (Standards.ISIC4, "71")),
        ((Standards.NACE2, "71.1"), (Standards.ISIC4, "711")),
        ((Standards.NACE2, "71.11"), (Standards.ISIC4, "7110")),
        ((Standards.NACE2, "71.12"), (Standards.ISIC4, "7110")),
        ((Standards.NACE2, "71.2"), (Standards.ISIC4, "712")),
        ((Standards.NACE2, "71.20"), (Standards.ISIC4, "7120")),
        ((Standards.NACE2, "72"), (Standards.ISIC4, "72")),
        ((Standards.NACE2, "72.1"), (Standards.ISIC4, "721")),
        ((Standards.NACE2, "72.11"), (Standards.ISIC4, "7210")),
        ((Standards.NACE2, "72.19"), (Standards.ISIC4, "7210")),
        ((Standards.NACE2, "72.2"), (Standards.ISIC4, "722")),
        ((Standards.NACE2, "72.20"), (Standards.ISIC4, "7220")),
        ((Standards.NACE2, "73"), (Standards.ISIC4, "73")),
        ((Standards.NACE2, "73.1"), (Standards.ISIC4, "731")),
        ((Standards.NACE2, "73.11"), (Standards.ISIC4, "7310")),
        ((Standards.NACE2, "73.12"), (Standards.ISIC4, "7310")),
        ((Standards.NACE2, "73.2"), (Standards.ISIC4, "732")),
        ((Standards.NACE2, "73.20"), (Standards.ISIC4, "7320")),
        ((Standards.NACE2, "74"), (Standards.ISIC4, "74")),
        ((Standards.NACE2, "74.1"), (Standards.ISIC4, "741")),
        ((Standards.NACE2, "74.10"), (Standards.ISIC4, "7410")),
        ((Standards.NACE2, "74.2"), (Standards.ISIC4, "742")),
        ((Standards.NACE2, "74.20"), (Standards.ISIC4, "7420")),
        ((Standards.NACE2, "74.3"), (Standards.ISIC4, "749")),
        ((Standards.NACE2, "74.30"), (Standards.ISIC4, "7490")),
        ((Standards.NACE2, "74.9"), (Standards.ISIC4, "749")),
        ((Standards.NACE2, "74.90"), (Standards.ISIC4, "7490")),
        ((Standards.NACE2, "75"), (Standards.ISIC4, "75")),
        ((Standards.NACE2, "75.0"), (Standards.ISIC4, "750")),
        ((Standards.NACE2, "75.00"), (Standards.ISIC4, "7500")),
        ((Standards.NACE2, "N"), (Standards.ISIC4, "N")),
        ((Standards.NACE2, "77"), (Standards.ISIC4, "77")),
        ((Standards.NACE2, "77.1"), (Standards.ISIC4, "771")),
        ((Standards.NACE2, "77.11"), (Standards.ISIC4, "7710")),
        ((Standards.NACE2, "77.12"), (Standards.ISIC4, "7710")),
        ((Standards.NACE2, "77.2"), (Standards.ISIC4, "772")),
        ((Standards.NACE2, "77.21"), (Standards.ISIC4, "7721")),
        ((Standards.NACE2, "77.22"), (Standards.ISIC4, "7722")),
        ((Standards.NACE2, "77.29"), (Standards.ISIC4, "7729")),
        ((Standards.NACE2, "77.3"), (Standards.ISIC4, "773")),
        ((Standards.NACE2, "77.31"), (Standards.ISIC4, "7730")),
        ((Standards.NACE2, "77.32"), (Standards.ISIC4, "7730")),
        ((Standards.NACE2, "77.33"), (Standards.ISIC4, "7730")),
        ((Standards.NACE2, "77.34"), (Standards.ISIC4, "7730")),
        ((Standards.NACE2, "77.35"), (Standards.ISIC4, "7730")),
        ((Standards.NACE2, "77.39"), (Standards.ISIC4, "7730")),
        ((Standards.NACE2, "77.4"), (Standards.ISIC4, "774")),
        ((Standards.NACE2, "77.40"), (Standards.ISIC4, "7740")),
        ((Standards.NACE2, "78"), (Standards.ISIC4, "78")),
        ((Standards.NACE2, "78.1"), (Standards.ISIC4, "781")),
        ((Standards.NACE2, "78.10"), (Standards.ISIC4, "7810")),
        ((Standards.NACE2, "78.2"), (Standards.ISIC4, "782")),
        ((Standards.NACE2, "78.20"), (Standards.ISIC4, "7820")),
        ((Standards.NACE2, "78.3"), (Standards.ISIC4, "783")),
        ((Standards.NACE2, "78.30"), (Standards.ISIC4, "7830")),
        ((Standards.NACE2, "79"), (Standards.ISIC4, "79")),
        ((Standards.NACE2, "79.1"), (Standards.ISIC4, "791")),
        ((Standards.NACE2, "79.11"), (Standards.ISIC4, "7911")),
        ((Standards.NACE2, "79.12"), (Standards.ISIC4, "7912")),
        ((Standards.NACE2, "79.9"), (Standards.ISIC4, "799")),
        ((Standards.NACE2, "79.90"), (Standards.ISIC4, "7990")),
        ((Standards.NACE2, "80"), (Standards.ISIC4, "80")),
        ((Standards.NACE2, "80.1"), (Standards.ISIC4, "801")),
        ((Standards.NACE2, "80.10"), (Standards.ISIC4, "8010")),
        ((Standards.NACE2, "80.2"), (Standards.ISIC4, "802")),
        ((Standards.NACE2, "80.20"), (Standards.ISIC4, "8020")),
        ((Standards.NACE2, "80.3"), (Standards.ISIC4, "803")),
        ((Standards.NACE2, "80.30"), (Standards.ISIC4, "8030")),
        ((Standards.NACE2, "81"), (Standards.ISIC4, "81")),
        ((Standards.NACE2, "81.1"), (Standards.ISIC4, "811")),
        ((Standards.NACE2, "81.10"), (Standards.ISIC4, "8110")),
        ((Standards.NACE2, "81.2"), (Standards.ISIC4, "812")),
        ((Standards.NACE2, "81.21"), (Standards.ISIC4, "8121")),
        ((Standards.NACE2, "81.22"), (Standards.ISIC4, "8129")),
        ((Standards.NACE2, "81.29"), (Standards.ISIC4, "8129")),
        ((Standards.NACE2, "81.3"), (Standards.ISIC4, "813")),
        ((Standards.NACE2, "81.30"), (Standards.ISIC4, "8130")),
        ((Standards.NACE2, "82"), (Standards.ISIC4, "82")),
        ((Standards.NACE2, "82.1"), (Standards.ISIC4, "821")),
        ((Standards.NACE2, "82.11"), (Standards.ISIC4, "8211")),
        ((Standards.NACE2, "82.19"), (Standards.ISIC4, "8219")),
        ((Standards.NACE2, "82.2"), (Standards.ISIC4, "822")),
        ((Standards.NACE2, "82.20"), (Standards.ISIC4, "8220")),
        ((Standards.NACE2, "82.3"), (Standards.ISIC4, "823")),
        ((Standards.NACE2, "82.30"), (Standards.ISIC4, "8230")),
        ((Standards.NACE2, "82.9"), (Standards.ISIC4, "829")),
        ((Standards.NACE2, "82.91"), (Standards.ISIC4, "8291")),
        ((Standards.NACE2, "82.92"), (Standards.ISIC4, "8292")),
        ((Standards.NACE2, "82.99"), (Standards.ISIC4, "8299")),
        ((Standards.NACE2, "O"), (Standards.ISIC4, "O")),
        ((Standards.NACE2, "84"), (Standards.ISIC4, "84")),
        ((Standards.NACE2, "84.1"), (Standards.ISIC4, "841")),
        ((Standards.NACE2, "84.11"), (Standards.ISIC4, "8411")),
        ((Standards.NACE2, "84.12"), (Standards.ISIC4, "8412")),
        ((Standards.NACE2, "84.13"), (Standards.ISIC4, "8413")),
        ((Standards.NACE2, "84.2"), (Standards.ISIC4, "842")),
        ((Standards.NACE2, "84.21"), (Standards.ISIC4, "8421")),
        ((Standards.NACE2, "84.22"), (Standards.ISIC4, "8422")),
        ((Standards.NACE2, "84.23"), (Standards.ISIC4, "8423")),
        ((Standards.NACE2, "84.24"), (Standards.ISIC4, "8423")),
        ((Standards.NACE2, "84.25"), (Standards.ISIC4, "8423")),
        ((Standards.NACE2, "84.3"), (Standards.ISIC4, "843")),
        ((Standards.NACE2, "84.30"), (Standards.ISIC4, "8430")),
        ((Standards.NACE2, "P"), (Standards.ISIC4, "P")),
        ((Standards.NACE2, "85"), (Standards.ISIC4, "85")),
        ((Standards.NACE2, "85.1"), (Standards.ISIC4, "851")),
        ((Standards.NACE2, "85.10"), (Standards.ISIC4, "8510")),
        ((Standards.NACE2, "85.2"), (Standards.ISIC4, "851")),
        ((Standards.NACE2, "85.20"), (Standards.ISIC4, "8510")),
        ((Standards.NACE2, "85.3"), (Standards.ISIC4, "852")),
        ((Standards.NACE2, "85.31"), (Standards.ISIC4, "8521")),
        ((Standards.NACE2, "85.32"), (Standards.ISIC4, "8522")),
        ((Standards.NACE2, "85.4"), (Standards.ISIC4, "853")),
        ((Standards.NACE2, "85.41"), (Standards.ISIC4, "8530")),
        ((Standards.NACE2, "85.42"), (Standards.ISIC4, "8530")),
        ((Standards.NACE2, "85.5"), (Standards.ISIC4, "854")),
        ((Standards.NACE2, "85.51"), (Standards.ISIC4, "8541")),
        ((Standards.NACE2, "85.52"), (Standards.ISIC4, "8542")),
        ((Standards.NACE2, "85.53"), (Standards.ISIC4, "8549")),
        ((Standards.NACE2, "85.59"), (Standards.ISIC4, "8549")),
        ((Standards.NACE2, "85.6"), (Standards.ISIC4, "855")),
        ((Standards.NACE2, "85.60"), (Standards.ISIC4, "8550")),
        ((Standards.NACE2, "Q"), (Standards.ISIC4, "Q")),
        ((Standards.NACE2, "86"), (Standards.ISIC4, "86")),
        ((Standards.NACE2, "86.1"), (Standards.ISIC4, "861")),
        ((Standards.NACE2, "86.10"), (Standards.ISIC4, "8610")),
        ((Standards.NACE2, "86.2"), (Standards.ISIC4, "862")),
        ((Standards.NACE2, "86.21"), (Standards.ISIC4, "8620")),
        ((Standards.NACE2, "86.22"), (Standards.ISIC4, "8620")),
        ((Standards.NACE2, "86.23"), (Standards.ISIC4, "8620")),
        ((Standards.NACE2, "86.9"), (Standards.ISIC4, "869")),
        ((Standards.NACE2, "86.90"), (Standards.ISIC4, "8690")),
        ((Standards.NACE2, "87"), (Standards.ISIC4, "87")),
        ((Standards.NACE2, "87.1"), (Standards.ISIC4, "871")),
        ((Standards.NACE2, "87.10"), (Standards.ISIC4, "8710")),
        ((Standards.NACE2, "87.2"), (Standards.ISIC4, "872")),
        ((Standards.NACE2, "87.20"), (Standards.ISIC4, "8720")),
        ((Standards.NACE2, "87.3"), (Standards.ISIC4, "873")),
        ((Standards.NACE2, "87.30"), (Standards.ISIC4, "8730")),
        ((Standards.NACE2, "87.9"), (Standards.ISIC4, "879")),
        ((Standards.NACE2, "87.90"), (Standards.ISIC4, "8790")),
        ((Standards.NACE2, "88"), (Standards.ISIC4, "88")),
        ((Standards.NACE2, "88.1"), (Standards.ISIC4, "881")),
        ((Standards.NACE2, "88.10"), (Standards.ISIC4, "8810")),
        ((Standards.NACE2, "88.9"), (Standards.ISIC4, "889")),
        ((Standards.NACE2, "88.91"), (Standards.ISIC4, "8890")),
        ((Standards.NACE2, "88.99"), (Standards.ISIC4, "8890")),
        ((Standards.NACE2, "R"), (Standards.ISIC4, "R")),
        ((Standards.NACE2, "90"), (Standards.ISIC4, "90")),
        ((Standards.NACE2, "90.0"), (Standards.ISIC4, "900")),
        ((Standards.NACE2, "90.01"), (Standards.ISIC4, "9000")),
        ((Standards.NACE2, "90.02"), (Standards.ISIC4, "9000")),
        ((Standards.NACE2, "90.03"), (Standards.ISIC4, "9000")),
        ((Standards.NACE2, "90.04"), (Standards.ISIC4, "9000")),
        ((Standards.NACE2, "91"), (Standards.ISIC4, "91")),
        ((Standards.NACE2, "91.0"), (Standards.ISIC4, "910")),
        ((Standards.NACE2, "91.01"), (Standards.ISIC4, "9101")),
        ((Standards.NACE2, "91.02"), (Standards.ISIC4, "9102")),
        ((Standards.NACE2, "91.03"), (Standards.ISIC4, "9102")),
        ((Standards.NACE2, "91.04"), (Standards.ISIC4, "9103")),
        ((Standards.NACE2, "92"), (Standards.ISIC4, "92")),
        ((Standards.NACE2, "92.0"), (Standards.ISIC4, "920")),
        ((Standards.NACE2, "92.00"), (Standards.ISIC4, "9200")),
        ((Standards.NACE2, "93"), (Standards.ISIC4, "93")),
        ((Standards.NACE2, "93.1"), (Standards.ISIC4, "931")),
        ((Standards.NACE2, "93.11"), (Standards.ISIC4, "9311")),
        ((Standards.NACE2, "93.12"), (Standards.ISIC4, "9312")),
        ((Standards.NACE2, "93.13"), (Standards.ISIC4, "9311")),
        ((Standards.NACE2, "93.19"), (Standards.ISIC4, "9319")),
        ((Standards.NACE2, "93.2"), (Standards.ISIC4, "932")),
        ((Standards.NACE2, "93.21"), (Standards.ISIC4, "9321")),
        ((Standards.NACE2, "93.29"), (Standards.ISIC4, "9329")),
        ((Standards.NACE2, "S"), (Standards.ISIC4, "S")),
        ((Standards.NACE2, "94"), (Standards.ISIC4, "94")),
        ((Standards.NACE2, "94.1"), (Standards.ISIC4, "941")),
        ((Standards.NACE2, "94.11"), (Standards.ISIC4, "9411")),
        ((Standards.NACE2, "94.12"), (Standards.ISIC4, "9412")),
        ((Standards.NACE2, "94.2"), (Standards.ISIC4, "942")),
        ((Standards.NACE2, "94.20"), (Standards.ISIC4, "9420")),
        ((Standards.NACE2, "94.9"), (Standards.ISIC4, "949")),
        ((Standards.NACE2, "94.91"), (Standards.ISIC4, "9491")),
        ((Standards.NACE2, "94.92"), (Standards.ISIC4, "9492")),
        ((Standards.NACE2, "94.99"), (Standards.ISIC4, "9499")),
        ((Standards.NACE2, "95"), (Standards.ISIC4, "95")),
        ((Standards.NACE2, "95.1"), (Standards.ISIC4, "951")),
        ((Standards.NACE2, "95.11"), (Standards.ISIC4, "9511")),
        ((Standards.NACE2, "95.12"), (Standards.ISIC4, "9512")),
        ((Standards.NACE2, "95.2"), (Standards.ISIC4, "952")),
        ((Standards.NACE2, "95.21"), (Standards.ISIC4, "9521")),
        ((Standards.NACE2, "95.22"), (Standards.ISIC4, "9522")),
        ((Standards.NACE2, "95.23"), (Standards.ISIC4, "9523")),
        ((Standards.NACE2, "95.24"), (Standards.ISIC4, "9524")),
        ((Standards.NACE2, "95.25"), (Standards.ISIC4, "9529")),
        ((Standards.NACE2, "95.29"), (Standards.ISIC4, "9529")),
        ((Standards.NACE2, "96"), (Standards.ISIC4, "96")),
        ((Standards.NACE2, "96.0"), (Standards.ISIC4, "960")),
        ((Standards.NACE2, "96.01"), (Standards.ISIC4, "9601")),
        ((Standards.NACE2, "96.02"), (Standards.ISIC4, "9602")),
        ((Standards.NACE2, "96.03"), (Standards.ISIC4, "9603")),
        ((Standards.NACE2, "96.04"), (Standards.ISIC4, "9609")),
        ((Standards.NACE2, "96.09"), (Standards.ISIC4, "9609")),
        ((Standards.NACE2, "T"), (Standards.ISIC4, "T")),
        ((Standards.NACE2, "97"), (Standards.ISIC4, "97")),
        ((Standards.NACE2, "97.0"), (Standards.ISIC4, "970")),
        ((Standards.NACE2, "97.00"), (Standards.ISIC4, "9700")),
        ((Standards.NACE2, "98"), (Standards.ISIC4, "98")),
        ((Standards.NACE2, "98.1"), (Standards.ISIC4, "981")),
        ((Standards.NACE2, "98.10"), (Standards.ISIC4, "9810")),
        ((Standards.NACE2, "98.2"), (Standards.ISIC4, "982")),
        ((Standards.NACE2, "98.20"), (Standards.ISIC4, "9820")),
        ((Standards.NACE2, "U"), (Standards.ISIC4, "U")),
        ((Standards.NACE2, "99"), (Standards.ISIC4, "99")),
        ((Standards.NACE2, "99.0"), (Standards.ISIC4, "990")),
        ((Standards.NACE2, "99.00"), (Standards.ISIC4, "9900")),
    ],
)
